########################################################################
#
#    Vision Macro - Python source code - file generated by vision
#    Monday 28 June 2010 18:00:49 
#    
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Daniel Stoffler, Michel Sanner and TSRI
#   
# revision: Guillaume Vareille
#  
#########################################################################
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/VisionInterface/Adt/Macro/ComputeGrids.py,v 1.8 2010/07/02 00:23:00 jren Exp $
#
# $Id: ComputeGrids.py,v 1.8 2010/07/02 00:23:00 jren Exp $
#

from NetworkEditor.macros import MacroNode
from NetworkEditor.macros import MacroNode
class ComputeGrids(MacroNode):
    '''
    First runs Prepare GPF on remote server to prepare a GPF based on the ligand library,
    then runs Autogrid on the remote server

    Inputs:
    port 1: LigandDB object containing info about the ligand library
    port 2: receptor_prepared object containing info about a receptor PDBQT file
    port 3: dpf_template object containing info about DPF template
    
    Outputs: 
    port 1: autogrid_results object containing info about autogrid results
    port 2: string to autogrid result URL

    '''

    def __init__(self, constrkw={}, name='ComputeGrids', **kw):
        kw['name'] = name
        apply( MacroNode.__init__, (self,), kw)

    def beforeAddingToNetwork(self, net):
        MacroNode.beforeAddingToNetwork(self, net)
        from WebServices.VisionInterface.WSNodes import wslib
        from Vision.StandardNodes import stdlib
        net.getEditor().addLibraryInstance(wslib,"WebServices.VisionInterface.WSNodes", "wslib")
        from WebServices.VisionInterface.WSNodes import addOpalServerAsCategory
        try:
            addOpalServerAsCategory("http://kryptonite.nbcr.net/opal2", replace=False)
        except:
            pass

    def afterAddingToNetwork(self):
        masterNet = self.macroNetwork
        from NetworkEditor.macros import MacroNode
        MacroNode.afterAddingToNetwork(self)
        from WebServices.VisionInterface.WSNodes import wslib
        from Vision.StandardNodes import stdlib
        ## building macro network ##
        ComputeGrids_18 = self
        from traceback import print_exc
        from WebServices.VisionInterface.WSNodes import wslib
        from Vision.StandardNodes import stdlib
        masterNet.getEditor().addLibraryInstance(wslib,"WebServices.VisionInterface.WSNodes", "wslib")
        from WebServices.VisionInterface.WSNodes import addOpalServerAsCategory
        try:
            addOpalServerAsCategory("http://kryptonite.nbcr.net/opal2", replace=False)
        except:
            pass
        try:
            ## saving node input Ports ##
            input_Ports_19 = self.macroNetwork.ipNode
            apply(input_Ports_19.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore MacroInputNode named input Ports in network self.macroNetwork"
            print_exc()
            input_Ports_19=None

        try:
            ## saving node output Ports ##
            output_Ports_20 = self.macroNetwork.opNode
            apply(output_Ports_20.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
            output_Ports_20.move(217, 471)
        except:
            print "WARNING: failed to restore MacroOutputNode named output Ports in network self.macroNetwork"
            print_exc()
            output_Ports_20=None

        try:
            ## saving node GetComputeGridsInputs ##
            from Vision.StandardNodes import Generic
            GetComputeGridsInputs_21 = Generic(constrkw={}, name='GetComputeGridsInputs', library=stdlib)
            self.macroNetwork.addNode(GetComputeGridsInputs_21,217,79)
            apply(GetComputeGridsInputs_21.addInputPort, (), {'singleConnection': True, 'name': 'ligands', 'cast': True, 'datatype': 'LigandDB', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'rect', 'color': '#FFCCFF', 'originalDatatype': 'None'})
            apply(GetComputeGridsInputs_21.addInputPort, (), {'singleConnection': True, 'name': 'receptor_pdbqt', 'cast': True, 'datatype': 'receptor_prepared', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'triangle', 'color': '#009900', 'originalDatatype': 'None'})
            apply(GetComputeGridsInputs_21.addInputPort, (), {'singleConnection': True, 'name': 'gpf_obj', 'cast': True, 'datatype': 'gpf_template', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'triangle', 'color': '#FF3333', 'originalDatatype': 'None'})
            apply(GetComputeGridsInputs_21.addOutputPort, (), {'name': 'gpf_template_path', 'datatype': 'string', 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white'})
            apply(GetComputeGridsInputs_21.addOutputPort, (), {'name': 'filter_file', 'datatype': 'string', 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white'})
            apply(GetComputeGridsInputs_21.addOutputPort, (), {'name': 'ligand_lib', 'datatype': 'string', 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white'})
            apply(GetComputeGridsInputs_21.addOutputPort, (), {'name': 'prepared_receptor', 'datatype': 'string', 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white'})
            code = """def doit(self, ligands, receptor_pdbqt, gpf_obj):
        gpf_path = gpf_obj.fullpath

        if not(os.path.exists(gpf_path)):
            print "ERROR: GPF template " + gpf_path + " does not exist!"
            return '''stop'''

        filter_file = ligands.filter_file
        ligand_lib = ligands.loc
        prepared_receptor = receptor_pdbqt.path

        pass

        self.outputData(gpf_template_path=gpf_path, filter_file=filter_file, ligand_lib=ligand_lib, prepared_receptor=prepared_receptor)

## to ouput data on port gpf_template_path use
## self.outputData(gpf_template_path=data)
## to ouput data on port filter_file use
## self.outputData(filter_file=data)
## to ouput data on port ligand_lib use
## self.outputData(ligand_lib=data)
## to ouput data on port prepared_receptor use
## self.outputData(prepared_receptor=data)






"""
            GetComputeGridsInputs_21.configure(function=code)
            apply(GetComputeGridsInputs_21.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore Generic named GetComputeGridsInputs in network self.macroNetwork"
            print_exc()
            GetComputeGridsInputs_21=None

        try:
            ## saving node prepareGPF_kryptonite_nbcr_net ##
            from NetworkEditor.items import FunctionNode
            prepareGPF_kryptonite_nbcr_net_22 = FunctionNode(functionOrString='prepareGPF_kryptonite_nbcr_net', host="http://kryptonite.nbcr.net/opal2", namedArgs={'singlelib': '', 'r_url': '', 'zpoints': '', 'filter_file_url': '', 'lib': '', 'ypoints': '', 'filter_file': '', 'gpf': '', 'xcenter': 'auto', 'urllib': '', 'p': '', 'r': '', 'o': '', 'zcenter': 'auto', 'v': False, 'userlib': '', 'xpoints': '', 'localRun': False, 'ycenter': 'auto', 'execPath': ''}, constrkw={'functionOrString': "'prepareGPF_kryptonite_nbcr_net'", 'host': '"http://kryptonite.nbcr.net/opal2"', 'namedArgs': {'singlelib': '', 'r_url': '', 'zpoints': '', 'filter_file_url': '', 'lib': '', 'ypoints': '', 'filter_file': '', 'gpf': '', 'xcenter': 'auto', 'urllib': '', 'p': '', 'r': '', 'o': '', 'zcenter': 'auto', 'v': False, 'userlib': '', 'xpoints': '', 'localRun': False, 'ycenter': 'auto', 'execPath': ''}}, name='prepareGPF_kryptonite_nbcr_net', library=wslib)
            self.macroNetwork.addNode(prepareGPF_kryptonite_nbcr_net_22,217,141)
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['singlelib'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['r_url'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['zpoints'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['filter_file_url'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['lib'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['ypoints'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['filter_file'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['gpf'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['xcenter'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['urllib'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['p'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['r'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['o'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['zcenter'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['v'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['userlib'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['xpoints'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['localRun'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['ycenter'].configure, (), {'defaultValue': None})
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['execPath'].configure, (), {'defaultValue': None})
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['singlelib'].widget.set(r"", run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['r_url'].widget.set(r"", run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['zpoints'].widget.set(r"", run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['filter_file_url'].widget.set(r"", run=False)
            apply(prepareGPF_kryptonite_nbcr_net_22.inputPortByName['lib'].widget.configure, (), {'choices': ('sample', 'NCIDS_SC', 'NCI_DS1', 'NCI_DS2', 'oldNCI', 'human_metabolome', 'chembridge_building_blocks', 'drugbank_nutraceutics', 'drugbank_smallmol', 'fda_approved')})
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['lib'].widget.set(r"", run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['ypoints'].widget.set(r"", run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['filter_file'].rebindWidget()
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['filter_file'].widget.set(r"", run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['filter_file'].unbindWidget()
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['gpf'].rebindWidget()
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['gpf'].widget.set(r"", run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['gpf'].unbindWidget()
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['xcenter'].widget.set(r"auto", run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['urllib'].rebindWidget()
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['urllib'].widget.set(r"", run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['urllib'].unbindWidget()
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['p'].widget.set(r"", run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['r'].rebindWidget()
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['r'].widget.set(r"", run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['r'].unbindWidget()
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['o'].widget.set(r"", run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['zcenter'].widget.set(r"auto", run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['v'].widget.set(0, run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['userlib'].widget.set(r"", run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['xpoints'].widget.set(r"", run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['localRun'].widget.set(0, run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['ycenter'].widget.set(r"auto", run=False)
            prepareGPF_kryptonite_nbcr_net_22.inputPortByName['execPath'].widget.set(r"", run=False)
            apply(prepareGPF_kryptonite_nbcr_net_22.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore FunctionNode named prepareGPF_kryptonite_nbcr_net in network self.macroNetwork"
            print_exc()
            prepareGPF_kryptonite_nbcr_net_22=None

        try:
            ## saving node autogrid_kryptonite_nbcr_net ##
            from NetworkEditor.items import FunctionNode
            autogrid_kryptonite_nbcr_net_23 = FunctionNode(functionOrString='autogrid_kryptonite_nbcr_net', host="http://kryptonite.nbcr.net/opal2", namedArgs={'p_url': '', 'infile_url': '', 'l': 'output.glg', 'o': False, 'p': '', 'localRun': False, 'inFile': '', 'execPath': ''}, constrkw={'functionOrString': "'autogrid_kryptonite_nbcr_net'", 'host': '"http://kryptonite.nbcr.net/opal2"', 'namedArgs': {'p_url': '', 'infile_url': '', 'l': 'output.glg', 'o': False, 'p': '', 'localRun': False, 'inFile': '', 'execPath': ''}}, name='autogrid_kryptonite_nbcr_net', library=wslib)
            self.macroNetwork.addNode(autogrid_kryptonite_nbcr_net_23,251,292)
            apply(autogrid_kryptonite_nbcr_net_23.inputPortByName['p_url'].configure, (), {'defaultValue': None})
            apply(autogrid_kryptonite_nbcr_net_23.inputPortByName['infile_url'].configure, (), {'defaultValue': None})
            apply(autogrid_kryptonite_nbcr_net_23.inputPortByName['l'].configure, (), {'defaultValue': None})
            apply(autogrid_kryptonite_nbcr_net_23.inputPortByName['o'].configure, (), {'defaultValue': None})
            apply(autogrid_kryptonite_nbcr_net_23.inputPortByName['p'].configure, (), {'defaultValue': None})
            apply(autogrid_kryptonite_nbcr_net_23.inputPortByName['localRun'].configure, (), {'defaultValue': None})
            apply(autogrid_kryptonite_nbcr_net_23.inputPortByName['inFile'].configure, (), {'defaultValue': None})
            apply(autogrid_kryptonite_nbcr_net_23.inputPortByName['execPath'].configure, (), {'defaultValue': None})
            autogrid_kryptonite_nbcr_net_23.inputPortByName['p_url'].rebindWidget()
            autogrid_kryptonite_nbcr_net_23.inputPortByName['p_url'].widget.set(r"", run=False)
            autogrid_kryptonite_nbcr_net_23.inputPortByName['p_url'].unbindWidget()
            autogrid_kryptonite_nbcr_net_23.inputPortByName['infile_url'].widget.set(r"", run=False)
            autogrid_kryptonite_nbcr_net_23.inputPortByName['l'].widget.set(r"output.glg", run=False)
            autogrid_kryptonite_nbcr_net_23.inputPortByName['o'].widget.set(0, run=False)
            autogrid_kryptonite_nbcr_net_23.inputPortByName['p'].widget.set(r"", run=False)
            autogrid_kryptonite_nbcr_net_23.inputPortByName['localRun'].widget.set(0, run=False)
            autogrid_kryptonite_nbcr_net_23.inputPortByName['inFile'].rebindWidget()
            autogrid_kryptonite_nbcr_net_23.inputPortByName['inFile'].widget.set(r"", run=False)
            autogrid_kryptonite_nbcr_net_23.inputPortByName['inFile'].unbindWidget()
            autogrid_kryptonite_nbcr_net_23.inputPortByName['execPath'].widget.set(r"", run=False)
            apply(autogrid_kryptonite_nbcr_net_23.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore FunctionNode named autogrid_kryptonite_nbcr_net in network self.macroNetwork"
            print_exc()
            autogrid_kryptonite_nbcr_net_23=None

        try:
            ## saving node GetMainURLFromList ##
            from WebServices.VisionInterface.WSNodes import GetMainURLFromListNode
            GetMainURLFromList_24 = GetMainURLFromListNode(constrkw={}, name='GetMainURLFromList', library=wslib)
            self.macroNetwork.addNode(GetMainURLFromList_24,251,348)
            apply(GetMainURLFromList_24.inputPortByName['urls'].configure, (), {'defaultValue': None})
            apply(GetMainURLFromList_24.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore GetMainURLFromListNode named GetMainURLFromList in network self.macroNetwork"
            print_exc()
            GetMainURLFromList_24=None

        try:
            ## saving node MakeAutogridResultObj ##
            from Vision.StandardNodes import Generic
            MakeAutogridResultObj_25 = Generic(constrkw={}, name='MakeAutogridResultObj', library=stdlib)
            self.macroNetwork.addNode(MakeAutogridResultObj_25,121,402)
            apply(MakeAutogridResultObj_25.addInputPort, (), {'singleConnection': True, 'name': 'autogrid_result_url', 'cast': True, 'datatype': 'string', 'defaultValue': None, 'required': True, 'height': 8, 'width': 12, 'shape': 'oval', 'color': 'white', 'originalDatatype': 'None'})
            apply(MakeAutogridResultObj_25.addOutputPort, (), {'name': 'autogrid_result_obj', 'datatype': 'autogrid_results', 'height': 8, 'width': 12, 'shape': 'triangle', 'color': '#FF33CC'})
            code = """def doit(self, autogrid_result_url):
        from AutoDockTools.VisionInterface.Adt.autogrid_results import autogrid_results

        agro = autogrid_results(autogrid_result_url, '''url''')
        
	pass
## to ouput data on port autogrid_result_obj use
        self.outputData(autogrid_result_obj=agro)

"""
            MakeAutogridResultObj_25.configure(function=code)
            apply(MakeAutogridResultObj_25.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore Generic named MakeAutogridResultObj in network self.macroNetwork"
            print_exc()
            MakeAutogridResultObj_25=None

        try:
            ## saving node GetURLFromList ##
            from WebServices.VisionInterface.WSNodes import GetURLFromListNode
            GetURLFromList_26 = GetURLFromListNode(constrkw={}, name='GetURLFromList', library=wslib)
            self.macroNetwork.addNode(GetURLFromList_26,110,198)
            apply(GetURLFromList_26.inputPortByName['urllist'].configure, (), {'defaultValue': None})
            apply(GetURLFromList_26.inputPortByName['ext'].configure, (), {'defaultValue': None})
            GetURLFromList_26.inputPortByName['ext'].widget.set(r"gpf", run=False)
            apply(GetURLFromList_26.configure, (), {'paramPanelImmediate': 1})
        except:
            print "WARNING: failed to restore GetURLFromListNode named GetURLFromList in network self.macroNetwork"
            print_exc()
            GetURLFromList_26=None

        #self.macroNetwork.run()
        self.macroNetwork.freeze()

        ## saving connections for network ComputeGrids ##
        input_Ports_19 = self.macroNetwork.ipNode
        if input_Ports_19 is not None and GetComputeGridsInputs_21 is not None:
            try:
                self.macroNetwork.connectNodes(
                    input_Ports_19, GetComputeGridsInputs_21, "new", "ligands", blocking=True
                    , splitratio=[0.25038057532685992, 0.40242243717082576])
            except:
                print "WARNING: failed to restore connection between input_Ports_19 and GetComputeGridsInputs_21 in network self.macroNetwork"
        if input_Ports_19 is not None and GetComputeGridsInputs_21 is not None:
            try:
                self.macroNetwork.connectNodes(
                    input_Ports_19, GetComputeGridsInputs_21, "new", "receptor_pdbqt", blocking=True
                    , splitratio=[0.31642654296910228, 0.49356822236979669])
            except:
                print "WARNING: failed to restore connection between input_Ports_19 and GetComputeGridsInputs_21 in network self.macroNetwork"
        if input_Ports_19 is not None and GetComputeGridsInputs_21 is not None:
            try:
                self.macroNetwork.connectNodes(
                    input_Ports_19, GetComputeGridsInputs_21, "new", "gpf_obj", blocking=True
                    , splitratio=[0.57570983312901203, 0.33826779179418875])
            except:
                print "WARNING: failed to restore connection between input_Ports_19 and GetComputeGridsInputs_21 in network self.macroNetwork"
        if GetComputeGridsInputs_21 is not None and prepareGPF_kryptonite_nbcr_net_22 is not None:
            try:
                self.macroNetwork.connectNodes(
                    GetComputeGridsInputs_21, prepareGPF_kryptonite_nbcr_net_22, "gpf_template_path", "gpf", blocking=True
                    , splitratio=[0.37911517364560754, 0.49588454022594075])
            except:
                print "WARNING: failed to restore connection between GetComputeGridsInputs_21 and prepareGPF_kryptonite_nbcr_net_22 in network self.macroNetwork"
        if GetComputeGridsInputs_21 is not None and prepareGPF_kryptonite_nbcr_net_22 is not None:
            try:
                self.macroNetwork.connectNodes(
                    GetComputeGridsInputs_21, prepareGPF_kryptonite_nbcr_net_22, "filter_file", "filter_file", blocking=True
                    , splitratio=[0.51555458245420727, 0.58910990532612562])
            except:
                print "WARNING: failed to restore connection between GetComputeGridsInputs_21 and prepareGPF_kryptonite_nbcr_net_22 in network self.macroNetwork"
        if GetComputeGridsInputs_21 is not None and prepareGPF_kryptonite_nbcr_net_22 is not None:
            try:
                self.macroNetwork.connectNodes(
                    GetComputeGridsInputs_21, prepareGPF_kryptonite_nbcr_net_22, "ligand_lib", "urllib", blocking=True
                    , splitratio=[0.45378244060628786, 0.49829462092378918])
            except:
                print "WARNING: failed to restore connection between GetComputeGridsInputs_21 and prepareGPF_kryptonite_nbcr_net_22 in network self.macroNetwork"
        if GetComputeGridsInputs_21 is not None and prepareGPF_kryptonite_nbcr_net_22 is not None:
            try:
                self.macroNetwork.connectNodes(
                    GetComputeGridsInputs_21, prepareGPF_kryptonite_nbcr_net_22, "prepared_receptor", "r", blocking=True
                    , splitratio=[0.30158184825681655, 0.46256232709378253])
            except:
                print "WARNING: failed to restore connection between GetComputeGridsInputs_21 and prepareGPF_kryptonite_nbcr_net_22 in network self.macroNetwork"
        if GetComputeGridsInputs_21 is not None and autogrid_kryptonite_nbcr_net_23 is not None:
            try:
                self.macroNetwork.connectNodes(
                    GetComputeGridsInputs_21, autogrid_kryptonite_nbcr_net_23, "prepared_receptor", "inFile", blocking=True
                    , splitratio=[0.63016045430148715, 0.62091422998177115])
            except:
                print "WARNING: failed to restore connection between GetComputeGridsInputs_21 and autogrid_kryptonite_nbcr_net_23 in network self.macroNetwork"
        if autogrid_kryptonite_nbcr_net_23 is not None and GetMainURLFromList_24 is not None:
            try:
                self.macroNetwork.connectNodes(
                    autogrid_kryptonite_nbcr_net_23, GetMainURLFromList_24, "result", "urls", blocking=True
                    , splitratio=[0.4713453370864038, 0.73699665503637379])
            except:
                print "WARNING: failed to restore connection between autogrid_kryptonite_nbcr_net_23 and GetMainURLFromList_24 in network self.macroNetwork"
        if GetMainURLFromList_24 is not None and MakeAutogridResultObj_25 is not None:
            try:
                self.macroNetwork.connectNodes(
                    GetMainURLFromList_24, MakeAutogridResultObj_25, "newurl", "autogrid_result_url", blocking=True
                    , splitratio=[0.37530325590010172, 0.67260462300696811])
            except:
                print "WARNING: failed to restore connection between GetMainURLFromList_24 and MakeAutogridResultObj_25 in network self.macroNetwork"
        output_Ports_20 = self.macroNetwork.opNode
        if MakeAutogridResultObj_25 is not None and output_Ports_20 is not None:
            try:
                self.macroNetwork.connectNodes(
                    MakeAutogridResultObj_25, output_Ports_20, "autogrid_result_obj", "new", blocking=True
                    , splitratio=[0.54860274312929591, 0.61692487705230459])
            except:
                print "WARNING: failed to restore connection between MakeAutogridResultObj_25 and output_Ports_20 in network self.macroNetwork"
        if GetMainURLFromList_24 is not None and output_Ports_20 is not None:
            try:
                self.macroNetwork.connectNodes(
                    GetMainURLFromList_24, output_Ports_20, "newurl", "new", blocking=True
                    , splitratio=[0.56961778623989434, 0.55443680742298707])
            except:
                print "WARNING: failed to restore connection between GetMainURLFromList_24 and output_Ports_20 in network self.macroNetwork"
        if prepareGPF_kryptonite_nbcr_net_22 is not None and GetURLFromList_26 is not None:
            try:
                self.macroNetwork.connectNodes(
                    prepareGPF_kryptonite_nbcr_net_22, GetURLFromList_26, "result", "urllist", blocking=True
                    , splitratio=[0.38550670487593142, 0.45424125807822219])
            except:
                print "WARNING: failed to restore connection between prepareGPF_kryptonite_nbcr_net_22 and GetURLFromList_26 in network self.macroNetwork"
        if GetURLFromList_26 is not None and autogrid_kryptonite_nbcr_net_23 is not None:
            try:
                self.macroNetwork.connectNodes(
                    GetURLFromList_26, autogrid_kryptonite_nbcr_net_23, "url", "p_url", blocking=True
                    , splitratio=[0.65566147293832433, 0.57782517914212228])
            except:
                print "WARNING: failed to restore connection between GetURLFromList_26 and autogrid_kryptonite_nbcr_net_23 in network self.macroNetwork"
        self.macroNetwork.runOnNewData.value = False

        ## modifying MacroInputNode dynamic ports
        input_Ports_19 = self.macroNetwork.ipNode
        input_Ports_19.outputPorts[1].configure(name='GetComputeGridsInputs_ligands')
        input_Ports_19.outputPorts[2].configure(name='GetComputeGridsInputs_receptor_pdbqt')
        input_Ports_19.outputPorts[3].configure(name='GetComputeGridsInputs_gpf_obj')

        ## modifying MacroOutputNode dynamic ports
        output_Ports_20 = self.macroNetwork.opNode
        output_Ports_20.inputPorts[1].configure(singleConnection='auto')
        output_Ports_20.inputPorts[2].configure(singleConnection='auto')
        output_Ports_20.inputPorts[1].configure(name='MakeAutogridResultObj_autogrid_result_obj')
        output_Ports_20.inputPorts[2].configure(name='GetMainURLFromList_newurl')
        ## configure MacroNode input ports
        ComputeGrids_18.inputPorts[0].configure(name='GetComputeGridsInputs_ligands')
        ComputeGrids_18.inputPorts[0].configure(datatype='LigandDB')
        ComputeGrids_18.inputPorts[1].configure(name='GetComputeGridsInputs_receptor_pdbqt')
        ComputeGrids_18.inputPorts[1].configure(datatype='receptor_prepared')
        ComputeGrids_18.inputPorts[2].configure(name='GetComputeGridsInputs_gpf_obj')
        ComputeGrids_18.inputPorts[2].configure(datatype='gpf_template')
        ## configure MacroNode output ports
        ComputeGrids_18.outputPorts[0].configure(name='MakeAutogridResultObj_autogrid_result_obj')
        ComputeGrids_18.outputPorts[0].configure(datatype='autogrid_results')
        ComputeGrids_18.outputPorts[1].configure(name='GetMainURLFromList_newurl')
        ComputeGrids_18.outputPorts[1].configure(datatype='string')

        ComputeGrids_18.shrink()

        ## reset modifications ##
        ComputeGrids_18.resetTags()
        ComputeGrids_18.buildOriginalList()



########################################################################
#
#    Vision Macro - Python source code - file generated by vision
#    Thursday 01 June 2006 11:30:03 
#    
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Daniel Stoffler, Michel Sanner and TSRI
#   
# revision: Guillaume Vareille
#  
#########################################################################
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/VisionInterface/PrepareAD3Receptor.py,v 1.1 2006/06/05 22:45:41 rhuey Exp $
#
# $Id: PrepareAD3Receptor.py,v 1.1 2006/06/05 22:45:41 rhuey Exp $
#

from NetworkEditor.macros import MacroNode
class PrepareAD3Receptor(MacroNode):

    def __init__(self, constrkw={}, name='Prepare AD3Receptor', **kw):
        kw['name'] = name
        apply( MacroNode.__init__, (self,), kw)

    def beforeAddingToNetwork(self, net):
        MacroNode.beforeAddingToNetwork(self, net)
        ## loading libraries ##
        from AutoDockTools.VisionInterface.AdtNodes import adtlib
        net.editor.addLibraryInstance(adtlib,"AutoDockTools.VisionInterface.AdtNodes", "adtlib")

        from MolKit.VisionInterface.MolKitNodes import molkitlib
        net.editor.addLibraryInstance(molkitlib,"MolKit.VisionInterface.MolKitNodes", "molkitlib")


    def afterAddingToNetwork(self):
        from NetworkEditor.macros import MacroNode
        MacroNode.afterAddingToNetwork(self)
        ## loading libraries ##
        from AutoDockTools.VisionInterface.AdtNodes import adtlib
        from MolKit.VisionInterface.MolKitNodes import molkitlib
        ## building macro network ##
        Prepare_AD3Receptor_16 = self
        from traceback import print_exc

        ## loading libraries ##
        from AutoDockTools.VisionInterface.AdtNodes import adtlib
        self.macroNetwork.getEditor().addLibraryInstance(adtlib,"AutoDockTools.VisionInterface.AdtNodes", "adtlib")

        from MolKit.VisionInterface.MolKitNodes import molkitlib
        self.macroNetwork.getEditor().addLibraryInstance(molkitlib,"MolKit.VisionInterface.MolKitNodes", "molkitlib")

        try:
            ## saving node input Ports ##
            input_Ports_17 = self.macroNetwork.ipNode
            input_Ports_17.move(165, 26)
        except:
            print "WARNING: failed to restore MacroInputNode named input Ports in network self.macroNetwork"
            print_exc()
            input_Ports_17=None

        try:
            ## saving node output Ports ##
            output_Ports_18 = self.macroNetwork.opNode
            output_Ports_18.move(165, 345)
        except:
            print "WARNING: failed to restore MacroOutputNode named output Ports in network self.macroNetwork"
            print_exc()
            output_Ports_18=None

        try:
            ## saving node Add Hydrogens ##
            from MolKit.VisionInterface.MolKitNodes import AddHydrogens
            Add_Hydrogens_19 = AddHydrogens(constrkw = {}, name='Add Hydrogens', library=molkitlib)
            self.macroNetwork.addNode(Add_Hydrogens_19,182,83)
            apply(Add_Hydrogens_19.inputPortByName['molecules'].configure, (), {'color': '#c64e70', 'cast': True, 'shape': 'oval'})
            apply(Add_Hydrogens_19.outputPortByName['molecules'].configure, (), {'color': '#c64e70', 'shape': 'oval'})
            apply(Add_Hydrogens_19.outputPortByName['new_h_ct'].configure, (), {'color': 'yellow', 'shape': 'circle'})
        except:
            print "WARNING: failed to restore AddHydrogens named Add Hydrogens in network self.macroNetwork"
            print_exc()
            Add_Hydrogens_19=None

        try:
            ## saving node Add Kollman Charges ##
            from MolKit.VisionInterface.MolKitNodes import AddKollmanCharges
            Add_Kollman_Charges_20 = AddKollmanCharges(constrkw = {}, name='Add Kollman Charges', library=molkitlib)
            self.macroNetwork.addNode(Add_Kollman_Charges_20,182,135)
            apply(Add_Kollman_Charges_20.inputPortByName['mols'].configure, (), {'color': '#c64e70', 'cast': True, 'shape': 'oval'})
            apply(Add_Kollman_Charges_20.outputPortByName['mols'].configure, (), {'color': '#c64e70', 'shape': 'oval'})
            apply(Add_Kollman_Charges_20.outputPortByName['charge_total'].configure, (), {'color': 'green', 'shape': 'circle'})
        except:
            print "WARNING: failed to restore AddKollmanCharges named Add Kollman Charges in network self.macroNetwork"
            print_exc()
            Add_Kollman_Charges_20=None

        try:
            ## saving node Add Solvation Parameters ##
            from AutoDockTools.VisionInterface.AdtNodes import Add_SolvationParameters
            Add_Solvation_Parameters_21 = Add_SolvationParameters(constrkw = {}, name='Add Solvation Parameters', library=adtlib)
            self.macroNetwork.addNode(Add_Solvation_Parameters_21,182,288)
            apply(Add_Solvation_Parameters_21.inputPortByName['mols'].configure, (), {'color': '#c64e70', 'cast': True, 'shape': 'oval'})
            apply(Add_Solvation_Parameters_21.outputPortByName['typed_mols'].configure, (), {'color': '#c64e70', 'shape': 'oval'})
            apply(Add_Solvation_Parameters_21.outputPortByName['AtSolPar'].configure, (), {'color': 'cyan', 'shape': 'oval'})
        except:
            print "WARNING: failed to restore Add_SolvationParameters named Add Solvation Parameters in network self.macroNetwork"
            print_exc()
            Add_Solvation_Parameters_21=None

        try:
            ## saving node Merge NonPolar Hydrogens ##
            from AutoDockTools.VisionInterface.AdtNodes import MergeNonPolarHydrogens
            Merge_NonPolar_Hydrogens_22 = MergeNonPolarHydrogens(constrkw = {}, name='Merge NonPolar Hydrogens', library=adtlib)
            self.macroNetwork.addNode(Merge_NonPolar_Hydrogens_22,182,236)
            apply(Merge_NonPolar_Hydrogens_22.inputPortByName['mols'].configure, (), {'color': '#c64e70', 'cast': True, 'shape': 'oval'})
            apply(Merge_NonPolar_Hydrogens_22.inputPortByName['renumber'].configure, (), {'color': 'yellow', 'cast': True, 'shape': 'circle'})
            apply(Merge_NonPolar_Hydrogens_22.outputPortByName['mols'].configure, (), {'color': '#c64e70', 'shape': 'oval'})
            apply(Merge_NonPolar_Hydrogens_22.outputPortByName['num_nphs'].configure, (), {'color': 'yellow', 'shape': 'circle'})
        except:
            print "WARNING: failed to restore MergeNonPolarHydrogens named Merge NonPolar Hydrogens in network self.macroNetwork"
            print_exc()
            Merge_NonPolar_Hydrogens_22=None

        try:
            ## saving node Merge Lone Pairs ##
            from AutoDockTools.VisionInterface.AdtNodes import MergeLonePairs
            Merge_Lone_Pairs_23 = MergeLonePairs(constrkw = {}, name='Merge Lone Pairs', library=adtlib)
            self.macroNetwork.addNode(Merge_Lone_Pairs_23,182,184)
            apply(Merge_Lone_Pairs_23.inputPortByName['mols'].configure, (), {'color': '#c64e70', 'cast': True, 'shape': 'oval'})
            apply(Merge_Lone_Pairs_23.inputPortByName['renumber'].configure, (), {'color': 'yellow', 'cast': True, 'shape': 'circle'})
            apply(Merge_Lone_Pairs_23.outputPortByName['mols'].configure, (), {'color': '#c64e70', 'shape': 'oval'})
            apply(Merge_Lone_Pairs_23.outputPortByName['num_lps'].configure, (), {'color': 'yellow', 'shape': 'circle'})
        except:
            print "WARNING: failed to restore MergeLonePairs named Merge Lone Pairs in network self.macroNetwork"
            print_exc()
            Merge_Lone_Pairs_23=None

        self.macroNetwork.freeze()

        ## saving connections for network Prepare AD3Receptor ##
        input_Ports_17 = self.macroNetwork.ipNode
        if input_Ports_17 is not None and Add_Hydrogens_19 is not None:
            try:
                self.macroNetwork.connectNodes(
                    input_Ports_17, Add_Hydrogens_19, "new", "molecules", blocking=True)
            except:
                print "WARNING: failed to restore connection between input_Ports_17 and Add_Hydrogens_19 in network self.macroNetwork"
        if Add_Hydrogens_19 is not None and Add_Kollman_Charges_20 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Add_Hydrogens_19, Add_Kollman_Charges_20, "molecules", "mols", blocking=True)
            except:
                print "WARNING: failed to restore connection between Add_Hydrogens_19 and Add_Kollman_Charges_20 in network self.macroNetwork"
        if Add_Kollman_Charges_20 is not None and Merge_Lone_Pairs_23 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Add_Kollman_Charges_20, Merge_Lone_Pairs_23, "mols", "mols", blocking=True)
            except:
                print "WARNING: failed to restore connection between Add_Kollman_Charges_20 and Merge_Lone_Pairs_23 in network self.macroNetwork"
        if Merge_Lone_Pairs_23 is not None and Merge_NonPolar_Hydrogens_22 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Merge_Lone_Pairs_23, Merge_NonPolar_Hydrogens_22, "mols", "mols", blocking=True)
            except:
                print "WARNING: failed to restore connection between Merge_Lone_Pairs_23 and Merge_NonPolar_Hydrogens_22 in network self.macroNetwork"
        if Merge_NonPolar_Hydrogens_22 is not None and Add_Solvation_Parameters_21 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Merge_NonPolar_Hydrogens_22, Add_Solvation_Parameters_21, "mols", "mols", blocking=True)
            except:
                print "WARNING: failed to restore connection between Merge_NonPolar_Hydrogens_22 and Add_Solvation_Parameters_21 in network self.macroNetwork"
        output_Ports_18 = self.macroNetwork.opNode
        if Add_Solvation_Parameters_21 is not None and output_Ports_18 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Add_Solvation_Parameters_21, output_Ports_18, "typed_mols", "new", blocking=True)
            except:
                print "WARNING: failed to restore connection between Add_Solvation_Parameters_21 and output_Ports_18 in network self.macroNetwork"
        self.macroNetwork.unfreeze()

        Prepare_AD3Receptor_16.shrink()

        ## reset modifications ##
        Prepare_AD3Receptor_16.resetTags()
        Prepare_AD3Receptor_16.buildOriginalList()



#!/usr/bin/env python
#
# 
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/Utilities24/compute_rms_between_conformations.py,v 1.3 2012/04/05 21:12:25 rhuey Exp $
#
import os, glob
import numpy.oldnumeric as Numeric
from math import sqrt

from MolKit import Read
from AutoDockTools.Docking import Docking
from mglutil.math.rmsd import RMSDCalculator


def dist(coords1, coords2):
    """return distance between two atoms, a and b.
    """
    npts = len(coords1)
    pt1 = Numeric.add.reduce(coords1)/npts
    pt2 = Numeric.add.reduce(coords2)/npts
    d = Numeric.array(pt1) - Numeric.array(pt2)
    return sqrt(Numeric.sum(d*d))


if __name__ == '__main__':
    import sys
    import getopt


    def usage():
        "Print helpful, accurate usage statement to stdout."
        print "Usage: compute_rms_between_conformations.py -r reference"
        print
        print "  Description of command..."
        print "    Computes rms between two conformations of a molecule and stores it in 'summary_rms_results.txt'"
        print "      -f     first filename"
        print "      -s     second filename"
        print "  Optional parameters:"
        print "     [-x]    omit hydrogen atoms from the calculation"
        print "     [-o]    output filename"
        print "     [-v]    verbose output"


    # process command arguments
    try:
        opt_list, args = getopt.getopt(sys.argv[1:], 'f:s:o:xvh')
    except getopt.GetoptError, msg:
        print 'compute_rms_between_conformations.py: %s' %msg
        usage()
        sys.exit(2)

    # initialize required parameters
    #-f: first filename
    first =  None
    #-s: second filename
    second =  None
    #-o outputfilename
    outputfilename = "summary_rms_results.txt"
    # optional parameters
    #-x exclude hydrogen atoms from calculation
    omit_hydrogens = False
    #-v detailed output 
    verbose = None

    #'f:s:o:xvh'
    for o, a in opt_list:
        #print "o=", o, " a=", a
        if o in ('-f', '--f'):
            first = a
            if verbose: print 'set first filename to ', a
        if o in ('-s', '--s'):
            second = a
            if verbose: print 'set second filename to ', a
        if o in ('-o', '--o'):
            outputfilename = a
            if verbose: print 'set outputfilename to ', a
        if o in ('-x', '--x'):
            omit_hydrogens = True
            if omit_hydrogens: print 'set omit_hydrogens to ', True
        if o in ('-v', '--v'):
            verbose = True
            if verbose: print 'set verbose to ', True
        if o in ('-h', '--'):
            usage()
            sys.exit()

    if not first:
        print 'compute_rms_between_conformations: reference filename must be specified.'
        usage()
        sys.exit()

    if not second:
        print 'compute_rms_between_conformations: second filename must be specified.'
        usage()
        sys.exit()

    #process docking in reference directory
    #read the molecules
    first = Read(first)[0]
    second = Read(second)[0]
    assert len(first.allAtoms)==len(second.allAtoms)
    first_ats = first.allAtoms
    second_ats = second.allAtoms
    if omit_hydrogens:
        first_ats = first.allAtoms.get(lambda x: x.element!='H')
        second_ats = second.allAtoms.get(lambda x: x.element!='H')
    #setup rmsd tool
    rmsTool = RMSDCalculator(first_ats.coords)
    need_to_open = not os.path.exists(outputfilename)
    if need_to_open:
        fptr = open(outputfilename, 'w')
        ostr= "reference filename      test filename\t\trms \n"
        fptr.write(ostr)
    else:
        fptr = open(outputfilename, 'a')
   
    ostr = "% 10s,\t% 10s,  % 10.4f\n" %(first.parser.filename, second.parser.filename, rmsTool.computeRMSD(second_ats.coords))
    fptr.write(ostr)
    fptr.close()
    

# To execute this command type:
# compute_rms_between_conformations.py -f filename -s secondfilename 
#           -o  outputfilename  -v verbose
# NOTE: -f, -d and -t require arguments whereas the other, -v, sets a boolean




#########################################################################
#
# Date: Nov 2001 Authors: Michel Sanner
#
#    sanner@scripps.edu
#
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Michel Sanner and TSRI
#
#########################################################################

from NetworkEditor.items import NetworkNode
from AutoDockTools.VisionInterface.Adt.gpf_template import gpf_template

class GPFTemplateBrowser(NetworkNode):
    """
    A node that allows the user to browse for a GPF template with the extension .gpf
  
    Input: GPF template file with the extension .gpf
    Output: gpf_template object that contains info about the GPF template file
    """
    
    def __init__(self, name='GPFTemplateBrowser', **kw):
        kw['name'] = name
        apply( NetworkNode.__init__, (self,), kw )

        kw['name'] = name
        apply( NetworkNode.__init__, (self,), kw )
        ip = self.inputPortsDescr
        ip.append(datatype='string', name='gpf_template_file')

        filetypes = [('All supported files', '*.gpf')]

        self.widgetDescr['gpf_template_file'] = {
            'class':'NEEntryWithFileBrowser', 'master':'node', 'width':20,
            'filetypes':filetypes,
            'initialValue':'', 'labelCfg':{'text':'GPF template file: '}
            }

        op = self.outputPortsDescr
        op.append(datatype='gpf_template', name='gpf_template')

        code = """def doit(self, gpf_template_file):
    import os
    from AutoDockTools.VisionInterface.Adt.gpf_template import gpf_template

    gpf_template_file = os.path.abspath(gpf_template_file)

    if not(os.path.exists(gpf_template_file)):
        print "ERROR: GPF template file " + gpf_template_file + " does not exist!" 
        return 'stop'

    gpf_template = gpf_template(gpf_template_file)

    self.outputData(gpf_template=gpf_template)
"""
        self.setFunction(code)



#!/usr/bin/env python

import os
from string import find, strip

from MolKit import Read
from MolKit.molecule import AtomSet
from MolKit.pdbWriter import PdbqtWriter
from AutoDockTools.atomTypeTools import AutoDock4_AtomTyper




if __name__ == '__main__':
    import sys
    import getopt


    def usage():
        "Print helpful, accurate usage statement to stdout."
        print "Usage: pdbq_to_pdbqt.py -s ligand_stem"
        print
        print "    Description of command..."
        print "        [-s]    stem of ligand.pdbq file"
        print "    Optional parameters:"
        print "        [-o]    alternative pdbqt_filename"
        print "        [-v]    verbose output"


    # process command arguments
    try:
        opt_list, args = getopt.getopt(sys.argv[1:], 's:o:v')

    except getopt.GetoptError, msg:
        print 'pdbq_to_pdbqt.py: %s' %msg
        usage()
        sys.exit(2)

    # initialize required parameters
    #-s: pdbq_stem
    pdbq_filename =  None

    # optional parameters
    verbose = None
    pdbqt_filename = None

    #'s:v'
    for o, a in opt_list:
        if o in ('-s', '--s'):
            pdbq_filename = a + '.pdbq'
            if pdbqt_filename is None:
                pdbqt_filename = a + '.pdbqt'
            if verbose: 
                print 'set pdbq_filename to ', a, 
                print " and pdbqt_filename to ", pdbqt_filename
        if o in ('-o', '--o'):
            pdbqt_filename = a 
            if verbose: 
                print 'set pdbqt_filename to ', a
        if o in ('-v', '--v'):
            verbose = True
            if verbose: print 'set verbose to ', True
        if o in ('-h', '--'):
            usage()
            sys.exit()



    if not pdbq_filename:
        print 'pdbq_to_pdbqt: stem of pdbq_filename must be specified.'
        usage()
        sys.exit()

    #what about nucleic acids???

    mols = Read(pdbq_filename)
    if verbose: print 'read ', pdbq_filename
    mol = mols[0]
    mol.buildBondsByDistance()

    #possible clean-up???
    #need to type atoms + assign babel_types
    AD4_typer = AutoDock4_AtomTyper()
    AD4_typer.setAutoDockElements(mol)
    if verbose:
        print "set autodock4 autodock_element for ", mol.name

    writer = PdbqtWriter()
    fptr = open(pdbqt_filename, 'w')
    ctr = 0
    for line in mol.parser.allLines:
        #for at in mol.allAtoms:
        if find(line, 'ATOM')<0 and find(line, "HETA")<0:
            fptr.write(line)
        else:
            name = strip(line[12:16])
            #ats = mol.allAtoms.get(lambda x: x.name==name)
            ##there could be (?) two atoms with the same name
            #if len(ats)==1:
            #    this_atom = ats[0]
            #else:
            x_coords = float(line[30:38])
            y_coords = float(line[38:46])
            z_coords = float(line[46:54])
            #this_atom = mol.allAtoms.get(lambda x:x.coords[0]==x_coords)[0]
            this_atom = mol.allAtoms.get(lambda x:x.coords[0]==x_coords)
            if this_atom is None or len(this_atom)==0:
                print name, x_coords,' do not correspond to an atom in ', pdbq_filename
                raise RuntimeError
            elif len(this_atom)>1:
                if verbose: print "using y coord comparison also for ", this_atom.name[0], this_atom.number
                this_atom = this_atom.get(lambda x:x.coords[1]==y_coords)
                if this_atom is None or len(this_atom)==0:
                    print name, x_coords, y_coords, ' do not correspond to an atom in ', pdbq_filename
                    raise RuntimeError
                elif len(this_atom)>1:
                    if verbose: print "using z coord comparison also for ", this_atom.name[0], this_atom.number
                    this_atom = this_atom.get(lambda x:x.coords[2]==z_coords)
                    if this_atom is None or len(this_atom)==0:
                        print name, x_coords, y_coords, z_coords, ' do not correspond to an atom in ', pdbq_filename
                        raise RuntimeError
                    else:
                        #x and y and z coords were required
                        this_atom = this_atom[0]
                else:
                    #x and y coords were enough
                    this_atom = this_atom[0]

            else:
                #x coords were enough
                this_atom = this_atom[0]
                
            if this_atom.name=='c': 
                this_atom.name = 'Cl'
                this_atom.element = 'Cl'
                this_atom.autodock_element ='CL'
            elif this_atom.name=='b': 
                print "processing ", this_atom.name
                this_atom.name = 'Br'
                this_atom.element = 'Br'
                this_atom.autodock_element ='BR'
            elif this_atom.name=='f': 
                this_atom.name = 'Fe'
                this_atom.element = 'Fe'
                this_atom.autodock_element ='FE'
            writer.write_atom(fptr, this_atom)
        ctr = ctr + 1
    fptr.close()
    if verbose:
        print "wrote ", ctr, " atoms to", pdbqt_filename
    

# To execute this command type:
# pdbq_to_pdbqt.py -s pdbq_file_stem -v







#############################################################################
#
# Author: Ruth HUEY, Michel F. SANNER
#
# Copyright: M. Sanner TSRI 2000
#
#############################################################################


# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/autostart3Commands.py,v 1.3 2009/06/17 00:03:24 vareille Exp $
#
# $Id: autostart3Commands.py,v 1.3 2009/06/17 00:03:24 vareille Exp $
#
#
#
#
#
#

"""
This Module facilitates starting autogrid and autodock jobs and managing them

"""
from ViewerFramework.VFCommand import CommandGUI
from AutoDockTools.autostartCommands import ADKill, ADProcessManager,\
AutoStarter, AutoGridStarter, AutoDockStarter, AddAutoDockHost, removePCs,\
entropiaPresent, menuText

     

if entropiaPresent:
    from Entropia.EntropiaDef import entropia_job_dir
    from Entropia.EntropiaUI import EntropiaUI
    from Entropia.EntropiaEx import EntropiaError
    import ftplib



ADProcessManagerGUI=CommandGUI()
ADProcessManagerGUI.addMenuCommand('AutoTools3Bar', menuText['StartMB'], menuText['processManagerMB'])


AutoGridStarterGUI=CommandGUI()
AutoGridStarterGUI.addMenuCommand('AutoTools3Bar', menuText['StartMB'], menuText['startGridMB'])


AutoDockStarterGUI=CommandGUI()
AutoDockStarterGUI.addMenuCommand('AutoTools3Bar', menuText['StartMB'], menuText['startDockMB'])

        
AddAutoDockHostGUI=CommandGUI()
AddAutoDockHostGUI.addMenuCommand('AutoTools3Bar', menuText['StartMB'], menuText['editHostsMB'])

commandList = [
    {'name':'AD3start_autogrid','cmd':AutoGridStarter(),'gui':AutoGridStarterGUI},
    {'name':'AD3start_autodock','cmd':AutoDockStarter(),'gui':AutoDockStarterGUI},
    {'name':'AD3start_editHostMacros','cmd':AddAutoDockHost(),'gui':AddAutoDockHostGUI},
    ]

import sys, os
if os.name != 'nt': #not sys.platform == 'win32':
    commandList.insert(2,
    {'name':'ADstart_manage','cmd':ADProcessManager(),'gui':ADProcessManagerGUI})
else:
    import binaries
    os.environ['PATH'] = binaries.__path__[0]+";"+os.environ['PATH']
        
def initModule(vf):

    for dict in commandList:
        vf.addCommand(dict['cmd'],dict['name'],dict['gui'])

    if hasattr(vf,'GUI'):
        for item in vf.GUI.menuBars['AutoTools3Bar'].menubuttons.values():
            item.configure(background = 'tan')
            item.configure(underline = '-1')
    else:
        vf.addCommand(ADProcessManager(),'AD3start_manage')
        vf.addCommand(AutoGridStarter(), 'AD3start_autogrid')
        vf.addCommand(AutoDockStarter(), 'AD3start_autodock')



#
#
#  $Id: test_ADdpf.py,v 1.9 2014/04/21 17:20:00 rhuey Exp $
#
#


import unittest, glob, os
import time
from string import find, split

mv = None
ct = 0
totalCt = 27


class ADdpf_BaseTests(unittest.TestCase):
    """
    setUp + tearDown form a fixture: working environment for the testing code
    """
    
        
    def startViewer(self):
        global mv
        #print 'in test_AD startViewer'
        if mv is None:
            from MolKit import Read
            import Tkinter
            from Pmv.moleculeViewer import MoleculeViewer
            mv = MoleculeViewer(trapExceptions=False)
            mv.loadModule('autotorsCommands', 'AutoDockTools')
            mv.loadModule('autogpfCommands', 'AutoDockTools')
            mv.loadModule('autodpfCommands', 'AutoDockTools')
            #8/18:
            mv.loadModule('autoanalyzeCommands', 'AutoDockTools')
            mv.loadModule('deleteCommands', 'Pmv')
            mv.loadModule('selectionCommands', 'Pmv')
            #change warningMsg format
            mv.setUserPreference(('warningMsgFormat', 'printed'), log = 0)
            
        self.mv = mv


    def setUp(self):
        """
        clean-up
        """
        if not hasattr(self, 'mv'):
            self.startViewer()


    def tearDown(self):
        """
        clean-up
        """
        #print 'in gpf tearDown'
        global ct, totalCt
        #reset docked
        from AutoDockTools.DockingParameters import DockingParameters
        self.mv.dpo = DockingParameters()
        self.mv.dpo.vf=self.mv
        from AutoDockTools.GridParameters import GridParameters
        self.mv.gpo = GridParameters()
        self.mv.gpo.vf=self.mv

        #delete any molecules left due to errors
        for m in self.mv.Mols:
            self.mv.deleteMol(m)
        ct = ct + 1
        #print 'ct =', ct
        if ct==totalCt:
            print 'destroying mv'
            self.mv.Exit(0)
            del self.mv            
    

    def SA_GA_LS_GALS(self):    
        self.mv.ADdpf_writeSA("ref_SA.dpf")
        self.mv.ADdpf_writeGA("ref_GA.dpf")
        self.mv.ADdpf_writeLS("ref_LS.dpf")
        self.mv.ADdpf_writeGAlS("ref_GALS.dpf")



class ADdpf_readDLGTests(ADdpf_BaseTests):
    
    
    
    
    def test_dpf_readdpf(self):
        """reads a dpf and checks
        """ 
        self.mv.ADdpf_read('hsg1_ind.dpf')
        c=self.mv.dpo
        self.assertEqual(c.dpf_filename, "hsg1_ind.dpf")


    def test_dpf_read_empty_dpf(self):
        """checks empty dpf entry
        """
        self.assertRaises(IOError, self.mv.ADdpf_read, " ")

    def test_dpf_read_non_existent_dpf(self):
        """checks non-existent dpf
        """
        self.assertRaises(IOError, self.mv.ADdpf_read, "asd.hfd.dpf")

   
    def test_dpf_set_macro_molecule_file_name(self):
        """checks  macro mols filename
        """
        self.mv.ADdpf_readMacromolecule("hsg1.pdbqs")
        self.assertEqual(self.mv.dpo.receptor_filename,"hsg1.pdbqs")
             
    def test_dpf_read_empty_macro_mol(self):
   
        """checks empty macro mol entry
        """
        self.assertRaises(IOError, self.mv.ADdpf_readMacromolecule, " ")

    def test_dpf_read_non_existent_macro_mol(self):
        """checks non-existent macro mol        """
        self.assertRaises(IOError, self.mv.ADdpf_readMacromolecule, "asd.hfd.dpf")
    

    def test_choosen_macro_name(self):
        filename = 'hsg1.pdbqs'
        self.mv.ADdpf_readMacromolecule(filename)
        self.assertEqual('hsg1', self.mv.dpo.receptor_stem)
        

    def test_dpf_replace_random(self):
        """ checks by setting some values in place of random
        """
                       
        self.mv.ADdpf_read('hsg1_ind.dpf')
        self.mv.ADdpf_readFormattedLigand("ind.out.pdbq")
        teststring = "1.0 2.0 3.0"
        self.mv.ADdpf_setDpo(tran0=teststring)
        testfile = "whateveryouwant.dpf"
        self.mv.ADdpf_writeGALS(testfile)
        fptr = open(testfile)
        alllines = fptr.readlines()
        fptr.close()
        for l in alllines:
            if find(l, 'tran0')==0:
                break
        ll = split(l)
        testsplit = split(teststring)
        for i in range(1, 4):
            self.assertEqual(ll[i], testsplit[i-1])
   

    def test_choosen_ligand_name(self):
        
        """checks choosen ligand name
        """
        filename = 'ind.out.pdbq'
        self.mv.readMolecule(filename)
        lig_name = self.mv.Mols[0].name
        self.mv.ADdpf_chooseFormattedLigand(lig_name)
        self.assertEqual(self.mv.dpo.ligand.name, lig_name)
        
    def test_dpf_set_ligand_parameters(self):
        """ checks ligand name, ndihe, center, types
        """
        self.mv.readMolecule('ind.out.pdbq')
        self.mv.ADdpf_chooseFormattedLigand("ind_out")
        m=self.mv.Mols[0]
        #4assertions: move is ligand.parser.filename
        #ndihe == ligand.ndihe
        #types == ligand.types
        #about==ligand.center
        oldcen = m.getCenter()
        newcen = []
        for i in range(3):
            newcen.append(round(oldcen[i],3))
        m.center = newcen
        self.assertEqual(m.ndihe, self.mv.dpo['ndihe']['value'])
        self.assertEqual(m.types, self.mv.dpo['types']['value'])
        self.assertEqual(m.center, self.mv.dpo['about']['value'])
        self.assertEqual(os.path.basename(m.parser.filename), self.mv.dpo.ligand_filename)
   
    def test_dpf_read_empty_ligand(self):
   
        """checks empty ligand
        """
        self.assertRaises(IOError, self.mv.ADdpf_readFormattedLigand, " ")

    def test_dpf_read_non_existent_ligand(self):
        """checks non-existent ligand
        """
        self.assertRaises(IOError, self.mv.ADdpf_readFormattedLigand, "asd.hfd.dpf")

    
    def test_dpf_read_ligand_widget_exists(self):
        """checks for widget when read ligand called
        """
        self.mv.ADdpf_readFormattedLigand('ind.out.pdbq')
        c =self.mv.ADdpf_initLigand
        self.assertEqual(c.form.root.winfo_ismapped(),1)
        self.assertEqual(c.form.root.withdraw(),'')
     
   
    def test_search_parameters_simulated_annealing_replace(self):
        """checks after replacing rtrf value
        """
        self.mv.ADdpf_setDpo(rtrf='0.5')
        self.assertEqual(self.mv.dpo['rtrf']['value'],'0.5')

    
    def test_search_parameters_ga_parameters_change(self):
        """checks dpo value after replacing 'ga_mutation_rate'
        """
        d={}
        d['ga_mutation_rate'] = 0.5 
        apply(self.mv.ADdpf_setGAparameters, (), d)
        self.assertEqual(self.mv.dpo['ga_mutation_rate']['value'],0.5)
               
    
        
    def test_search_parameters_ga_parameters_values(self):
        """checks values in widget and file are same
        """
        self.mv.ADdpf_readFormattedLigand("ind.out.pdbq")
        self.mv.ADdpf_readMacromolecule("hsg1.pdbqs")
        testfile = "somename.dpf"
        self.mv.ADdpf_writeGALS(testfile)
        fptr=open(testfile)
        alllines=fptr.readlines()
        ll = [0,0]
        for i in alllines:        
            if find(i,'ga_window_size')==0:
                ll = split(i)
                break
        self.assertEqual(str(mv.dpo['ga_window_size']['value']), ll[1])
    

    def test_search_parameters_ga_parameters_replace(self):
        """checks in file after replacing in widget
        """
        self.mv.ADdpf_readFormattedLigand("ind.out.pdbq")
        self.mv.ADdpf_readMacromolecule("hsg1.pdbqs")
        d={}
        d['ga_pop_size'] = 2
        apply(mv.ADdpf_setGAparameters, (), d)
        testfile = "somename.dpf"
        self.mv.ADdpf_writeGALS(testfile)
        fptr=open(testfile)
        alllines=fptr.readlines()
        ll = [0,0]
        for i in alllines:        
            if find(i,'ga_pop_size')==0:
                ll=split(i)
                break
        self.assertEqual(ll[1],'2')
        
   
    def test_search_parameters_ls_parameters_values(self):
        """checks after replacing ls parameter
        """
        d={}
        d['ls_search_freq'] =0.5 
        apply(mv.ADdpf_setLSparameters, (), d)
        self.assertEqual(self.mv.dpo['ls_search_freq']['value'],0.5)
   

    def test_search_parameters_ls_parameters_replace(self):
        """checks ls  paarmeters in widget and file are same
        """
        self.mv.ADdpf_readFormattedLigand("ind.out.pdbq")
        self.mv.ADdpf_readMacromolecule("hsg1.pdbqs")
        d={}
        d['ls_search_freq'] = 0.02 
        apply(mv.ADdpf_setLSparameters, (), d)
        testfile = "somename.dpf"
        self.mv.ADdpf_writeGALS(testfile)
        fptr=open(testfile)
        alllines=fptr.readlines()
        fptr.close()
        ll = [0,0]
        for i in alllines:        
            if find(i,'ls_search_freq')==0:
                ll=split(i)
                break
        self.assertEqual(str(round(mv.dpo['ls_search_freq']['value'],2)),ll[1])

        
    def test_search_parameters_ls_parameters_change(self):
        """checks in file after replacing ls parameters in widget
        """
        self.mv.ADdpf_readFormattedLigand("ind.out.pdbq")
        self.mv.ADdpf_readMacromolecule("hsg1.pdbqs")
        d={}
        d['ls_search_freq'] = 0.02
        apply(mv.ADdpf_setLSparameters, (), d)
        testfile = "somename.dpf"
        self.mv.ADdpf_writeGALS(testfile)
        fptr=open(testfile)
        alllines=fptr.readlines()
        fptr.close()
        ll = [0,0]
        for i in alllines:        
            if find(i,'ls_search_freq')==0:
                ll=split(i)
                break
        self.assertEqual(ll[1], '0.02')
   

    def test_search_parameters_docking_parameters_values(self):
        """checks docking parameters after replacing
        """
        d={}
        d['rmstol'] =4.5 
        apply(mv.ADdpf_setDockingParameters, (), d)
        self.assertEqual(self.mv.dpo['rmstol']['value'],4.5)


    def test_search_parameters_docking_parameters_replace(self):
        """checks docking  paarmeters in widget and file are same
        """
        self.mv.ADdpf_readFormattedLigand("ind.out.pdbq")
        self.mv.ADdpf_readMacromolecule("hsg1.pdbqs")
        test_val = 222
        d={}
        d['sw_max_fail'] = test_val 
        apply(mv.ADdpf_setDockingParameters, (), d)
        testfile = "somename.dpf"
        self.mv.ADdpf_writeGALS(testfile)
        fptr=open(testfile)
        alllines=fptr.readlines()
        fptr.close()
        ll = [0,0]
        for line in alllines:        
            if find(line,'sw_max_fail')>-1:
                ll=split(line)
                break
        self.assertEqual(test_val,int(ll[1]))
        self.assertEqual(self.mv.dpo['sw_max_fail']['value'],test_val)
         

    def test_search_parameters_docking_parameters_change(self):
        """checks in file after replacing ls parameters in widget
        """
        self.mv.ADdpf_read('hsg1_ind.dpf')
        self.mv.ADdpf_readFormattedLigand("ind.out.pdbq")
        test_val = 333
        d={}
        d['sw_max_its'] = test_val
        apply(mv.ADdpf_setDockingParameters, (), d)
        testfile = "somename.dpf"
        self.mv.ADdpf_writeGALS(testfile)
        fptr=open(testfile)
        alllines=fptr.readlines()
        fptr.close()
        ll = [0,0]
        for i in alllines:        
            if find(i,'sw_max_its')==0:
                ll=split(i)
                break
        self.assertEqual(int(ll[1]),test_val)


    def test_sa_dpf_compare_lines(self):
        
        """checks ref_SA file and test_SA file are same
        """
        self.mv.ADdpf_readMacromolecule("hsg1.pdbqs")
        self.mv.ADdpf_readFormattedLigand("ind.out.pdbq")
        self.mv.ADdpf_writeSA("test_SA.dpf")
        testptr = open("test_SA.dpf")
        testlines = testptr.readlines()
        refptr = open("ref_SA.dpf")
        reflines = refptr.readlines()
        for refline,testline in zip(reflines,testlines):
            self.assertEqual(refline,testline)
            

    def test_ga_dpf_compare_lines(self):
        
        """checks ref_GA file and test_GA file are same
        """
        self.mv.ADdpf_readMacromolecule("hsg1.pdbqs")
        self.mv.ADdpf_readFormattedLigand("ind.out.pdbq")
        self.mv.ADdpf_writeGA("test_GA.dpf")
        testptr = open("test_GA.dpf")
        testlines = testptr.readlines()
        refptr = open("ref_GA.dpf")
        reflines = refptr.readlines()
        for refline,testline in zip(reflines,testlines):
            self.assertEqual(refline,testline)

    def test_ls_dpf_compare_lines(self):
        
        """checks ref_LS file and test_LS file are same
        """
        self.mv.ADdpf_readMacromolecule("hsg1.pdbqs")
        self.mv.ADdpf_readFormattedLigand("ind.out.pdbq")
        self.mv.ADdpf_writeLS("test_LS.dpf")
        testptr = open("test_LS.dpf")
        testlines = testptr.readlines()
        refptr = open("ref_LS.dpf")
        reflines = refptr.readlines()
        for refline,testline in zip(reflines,testlines):
            self.assertEqual(refline,testline)


    def test_gals_dpf_compare_lines(self):
        
        """checks ref_GALS file and test_GALS file are same
        """
        self.mv.ADdpf_readFormattedLigand("ind.out.pdbq")
        self.mv.ADdpf_readMacromolecule("hsg1.pdbqs")
        self.mv.ADdpf_readFormattedLigand("ind.out.pdbq")
        self.mv.ADdpf_writeGALS("test_GALS.dpf")
        testptr = open("test_GALS.dpf")
        testlines = testptr.readlines()
        refptr = open("ref_GALS.dpf")
        reflines = refptr.readlines()
        for refline,testline in zip(reflines,testlines):
            self.assertEqual(refline,testline)

        
if __name__ == '__main__':
    unittest.main()





#
#
#
#
# $Id: test_summarize_results4.py,v 1.2 2010/01/18 20:08:48 rhuey Exp $
#

import unittest, os, sys

class BaseTests(unittest.TestCase):

    def test_incomplete_dlg(self):
        """
    summarize_results4.py -d ."
    AutoDockTools/Tests directory contains failed docking 'partial.dlg'
        """
        cmd = 'set PYTHONPATH=%s'%sys.path[0]
        cmd = cmd + "; ../summarize_results4.py -d . " 
        result = os.system(cmd)
        print "result =", result
        self.assertEqual(result, 256)

if __name__ == '__main__':
    unittest.main()



########################################################################
#
#    Vision Macro - Python source code - file generated by vision
#    Tuesday 25 July 2006 11:59:24 
#    
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Daniel Stoffler, Michel Sanner and TSRI
#   
# revision: Guillaume Vareille
#  
#########################################################################
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/VisionInterface/recluster.py,v 1.1 2006/07/25 23:35:30 rhuey Exp $
#
# $Id: recluster.py,v 1.1 2006/07/25 23:35:30 rhuey Exp $
#

from NetworkEditor.macros import MacroNode
class recluster(MacroNode):

    def __init__(self, constrkw={}, name='recluster', **kw):
        kw['name'] = name
        apply( MacroNode.__init__, (self,), kw)

    def beforeAddingToNetwork(self, net):
        MacroNode.beforeAddingToNetwork(self, net)
        ## loading libraries ##
        from MolKit.VisionInterface.MolKitNodes import molkitlib
        net.editor.addLibraryInstance(molkitlib,"MolKit.VisionInterface.MolKitNodes", "molkitlib")

        from Vision.StandardNodes import stdlib
        net.editor.addLibraryInstance(stdlib,"Vision.StandardNodes", "stdlib")


    def afterAddingToNetwork(self):
        from NetworkEditor.macros import MacroNode
        MacroNode.afterAddingToNetwork(self)
        ## loading libraries ##
        from MolKit.VisionInterface.MolKitNodes import molkitlib
        from Vision.StandardNodes import stdlib
        ## building macro network ##
        recluster_11 = self
        from traceback import print_exc

        ## loading libraries ##
        from MolKit.VisionInterface.MolKitNodes import molkitlib
        self.macroNetwork.getEditor().addLibraryInstance(molkitlib,"MolKit.VisionInterface.MolKitNodes", "molkitlib")

        from Vision.StandardNodes import stdlib
        self.macroNetwork.getEditor().addLibraryInstance(stdlib,"Vision.StandardNodes", "stdlib")

        try:
            ## saving node input Ports ##
            input_Ports_12 = self.macroNetwork.ipNode
            input_Ports_12.move(172, 137)
        except:
            print "WARNING: failed to restore MacroInputNode named input Ports in network self.macroNetwork"
            print_exc()
            input_Ports_12=None

        try:
            ## saving node output Ports ##
            output_Ports_13 = self.macroNetwork.opNode
            output_Ports_13.move(172, 479)
        except:
            print "WARNING: failed to restore MacroOutputNode named output Ports in network self.macroNetwork"
            print_exc()
            output_Ports_13=None

        try:
            ## saving node Docking ##
            from Vision.StandardNodes import Generic
            Docking_16 = Generic(constrkw = {}, name='Docking', library=stdlib)
            self.macroNetwork.addNode(Docking_16,189,250)
            apply(Docking_16.addInputPort, (), {'name': 'docking_logs', 'cast': True, 'datatype': 'list', 'balloon': 'list of docking log files to be read into as a single Docking', 'height': 12, 'width': 12, 'shape': 'oval', 'color': 'cyan'})
            apply(Docking_16.addInputPort, (), {'name': 'rmsTool', 'cast': True, 'datatype': 'None', 'balloon': 'rmsTool to be used for clustering', 'required': False, 'height': 8, 'width': 12, 'shape': 'diamond', 'color': 'white'})
            apply(Docking_16.addOutputPort, (), {'name': 'docking', 'datatype': 'None', 'balloon': 'docking instance', 'height': 8, 'width': 12, 'shape': 'diamond', 'color': 'white'})
            code = """def doit(self, docking_logs, rmsTool):
        from AutoDockTools.Docking import Docking
        d = Docking()
        for f in docking_logs:
                d.readDlg(f)
        d.clusterer.rmsTool = rmsTool
        self.outputData(docking = d)           
                    
        
## to ouput data on port docking use
## self.outputData(docking=data)


"""
            Docking_16.configure(function=code)
        except:
            print "WARNING: failed to restore Generic named Docking in network self.macroNetwork"
            print_exc()
            Docking_16=None

        try:
            ## saving node rmsTool ##
            from Vision.StandardNodes import Generic
            rmsTool_17 = Generic(constrkw = {}, name='rmsTool', library=stdlib)
            self.macroNetwork.addNode(rmsTool_17,206,197)
            apply(rmsTool_17.addInputPort, (), {'name': 'crds', 'cast': True, 'datatype': 'coordinates3D', 'balloon': 'coordinates to use as reference for rms calculation.', 'height': 8, 'width': 12, 'shape': 'rect', 'color': 'green'})
            apply(rmsTool_17.addOutputPort, (), {'name': 'rmsTool', 'datatype': 'None', 'balloon': 'rmsTool created using crds as reference', 'height': 8, 'width': 12, 'shape': 'diamond', 'color': 'white'})
            code = """def doit(self, crds):
	from  mglutil.math.rmsd  import RMSDCalculator
	rmsTool = RMSDCalculator(crds)
	self.outputData(rmsTool = rmsTool)
	
"""
            rmsTool_17.configure(function=code)
        except:
            print "WARNING: failed to restore Generic named rmsTool in network self.macroNetwork"
            print_exc()
            rmsTool_17=None

        try:
            ## saving node Read Molecule ##
            from MolKit.VisionInterface.MolKitNodes import ReadMolecule
            Read_Molecule_18 = ReadMolecule(constrkw = {}, name='Read Molecule', library=molkitlib)
            self.macroNetwork.addNode(Read_Molecule_18,243,16)
            apply(Read_Molecule_18.inputPortByName['filename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Read_Molecule_18.outputPortByName['MolSets'].configure, (), {'color': '#c64e70', 'shape': 'oval'})
            Read_Molecule_18.inputPortByName['filename'].widget.set("ind.pdbqt", run=False)
        except:
            print "WARNING: failed to restore ReadMolecule named Read Molecule in network self.macroNetwork"
            print_exc()
            Read_Molecule_18=None

        try:
            ## saving node Index ##
            from Vision.StandardNodes import Index
            Index_19 = Index(constrkw = {}, name='Index', library=stdlib)
            self.macroNetwork.addNode(Index_19,243,66)
            apply(Index_19.inputPortByName['data'].configure, (), {'datatype': 'MoleculeSet', 'cast': True, 'shape': 'oval', 'color': '#c64e70'})
            apply(Index_19.inputPortByName['index'].configure, (), {'color': 'yellow', 'cast': True, 'shape': 'circle'})
            apply(Index_19.outputPortByName['data'].configure, (), {'color': 'white', 'shape': 'diamond'})
        except:
            print "WARNING: failed to restore Index named Index in network self.macroNetwork"
            print_exc()
            Index_19=None

        try:
            ## saving node Get allAtoms.coords ##
            from Vision.StandardNodes import GetAttr
            Get_allAtoms_coords_20 = GetAttr(constrkw = {}, name='Get allAtoms.coords', library=stdlib)
            self.macroNetwork.addNode(Get_allAtoms_coords_20,243,115)
            apply(Get_allAtoms_coords_20.inputPortByName['objects'].configure, (), {'color': 'white', 'cast': True, 'shape': 'diamond'})
            apply(Get_allAtoms_coords_20.inputPortByName['attr'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Get_allAtoms_coords_20.outputPortByName['attrs'].configure, (), {'color': 'cyan', 'shape': 'oval'})
            apply(Get_allAtoms_coords_20.inputPortByName['attr'].widget.configure, (), {'choices': ('AAradii', 'AtomRadiiPatterns', 'NodesFromName', 'ROOT', 'TORSDOF', '_MarkTree', '__cmp__', '__doc__', '__eq__', '__hash__', '__init__', '__module__', '__ne__', '__repr__', '__str__', '_atomRadius', '_copyNode', '_copy_atom_attr', '_fit_atom_into_tree', '_numberOfDeletedNodes', 'addBond', 'adopt', 'allAtoms', 'assignUniqIndex', 'atmNum', 'attach_nonbonded_fragments', 'bonds', 'bondsflag', 'buildBondsBhtree', 'buildBondsByDistance', 'buildBondsByDistanceOnAtoms', 'buildBrokenBonds', 'chains', 'childByName', 'children', 'childrenName', 'childrenSetClass', 'closerThan', 'compare', 'compiled_patterns', 'configureProgressBar', 'copy', 'defaultRadii', 'deleteSubTree', 'dump', 'elementType', 'findLevels', 'findType', 'full_name', 'get', 'getAtoms', 'getCenter', 'getNext', 'getParentOfType', 'getPrevious', 'getRoot', 'getTypeList', 'hasBonds', 'hasSS', 'isAbove', 'isBelow', 'levels', 'makeNameUniq', 'merge', 'mergeNPH', 'name', 'ndihe', 'p', 'parent', 'parser', 'read', 'remove', 'removeAllHydrogens', 'removeBond', 'secondaryStructure', 'secondaryStructureFromFile', 'secondaryStructureFromStride', 'setClass', 'split', 'subTree', 'top', 'torTree', 'updateProgressBar', 'write')})
            Get_allAtoms_coords_20.inputPortByName['attr'].widget.set("allAtoms.coords", run=False)
            apply(Get_allAtoms_coords_20.configure, (), {'expanded': True})
        except:
            print "WARNING: failed to restore GetAttr named Get allAtoms.coords in network self.macroNetwork"
            print_exc()
            Get_allAtoms_coords_20=None

        try:
            ## saving node Get clusterer ##
            from Vision.StandardNodes import GetAttr
            Get_clusterer_21 = GetAttr(constrkw = {}, name='Get clusterer', library=stdlib)
            self.macroNetwork.addNode(Get_clusterer_21,189,306)
            apply(Get_clusterer_21.inputPortByName['objects'].configure, (), {'color': 'white', 'cast': True, 'shape': 'diamond'})
            apply(Get_clusterer_21.inputPortByName['attr'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Get_clusterer_21.outputPortByName['attrs'].configure, (), {'color': 'cyan', 'shape': 'oval'})
            apply(Get_clusterer_21.inputPortByName['attr'].widget.configure, (), {'choices': ('__doc__', '__init__', '__module__', 'addConformations', 'ch', 'clusterer', 'clusterer_dict', 'defaultParser', 'dlo_list', 'flex_res', 'ligMol', 'parser', 'readDlg', 'readEntropiaResults', 'readXMLResults', 'set_ligand', 'version', 'warnings', 'writeConformation', 'write_current_conformation')})
            Get_clusterer_21.inputPortByName['attr'].widget.set("clusterer", run=False)
            apply(Get_clusterer_21.configure, (), {'expanded': True})
        except:
            print "WARNING: failed to restore GetAttr named Get clusterer in network self.macroNetwork"
            print_exc()
            Get_clusterer_21=None

        try:
            ## saving node Index ##
            from Vision.StandardNodes import Index
            Index_22 = Index(constrkw = {}, name='Index', library=stdlib)
            self.macroNetwork.addNode(Index_22,188,383)
            apply(Index_22.inputPortByName['data'].configure, (), {'datatype': 'list', 'cast': True, 'shape': 'oval', 'color': 'cyan'})
            apply(Index_22.inputPortByName['index'].configure, (), {'color': 'yellow', 'cast': True, 'shape': 'circle'})
            apply(Index_22.outputPortByName['data'].configure, (), {'color': 'white', 'shape': 'diamond'})
        except:
            print "WARNING: failed to restore Index named Index in network self.macroNetwork"
            print_exc()
            Index_22=None

        try:
            ## saving node make clustering ##
            from Vision.StandardNodes import Generic
            make_clustering_23 = Generic(constrkw = {}, name='make clustering', library=stdlib)
            self.macroNetwork.addNode(make_clustering_23,189,432)
            apply(make_clustering_23.addInputPort, (), {'name': 'clusterer', 'cast': True, 'datatype': 'None', 'balloon': 'clusterer which will make the new clustering', 'height': 8, 'width': 12, 'shape': 'diamond', 'color': 'white'})
            apply(make_clustering_23.addInputPort, (), {'name': 'tolerance', 'cast': True, 'datatype': 'float', 'balloon': 'rms tolerance for the new clustering', 'height': 12, 'width': 12, 'shape': 'circle', 'color': 'green'})
            apply(make_clustering_23.addOutputPort, (), {'name': 'clustering', 'datatype': 'None', 'balloon': 'clustering at newest rms', 'height': 8, 'width': 12, 'shape': 'diamond', 'color': 'white'})
            code = """def doit(self, clusterer, tolerance):
	clusterer.make_clustering(tolerance)
	self.outputData(clustering = clusterer.clustering_dict[tolerance])
"""
            make_clustering_23.configure(function=code)
        except:
            print "WARNING: failed to restore Generic named make clustering in network self.macroNetwork"
            print_exc()
            make_clustering_23=None

        try:
            ## saving node Dial ##
            from Vision.StandardNodes import DialNE
            Dial_24 = DialNE(constrkw = {}, name='Dial', library=stdlib)
            self.macroNetwork.addNode(Dial_24,233,380)
            apply(Dial_24.inputPortByName['dial'].configure, (), {'color': 'green', 'cast': True, 'shape': 'circle'})
            apply(Dial_24.inputPortByName['mini'].configure, (), {'color': 'green', 'cast': True, 'shape': 'circle'})
            apply(Dial_24.inputPortByName['maxi'].configure, (), {'color': 'green', 'cast': True, 'shape': 'circle'})
            apply(Dial_24.outputPortByName['value'].configure, (), {'color': 'green', 'shape': 'circle'})
            Dial_24.inputPortByName['dial'].widget.set(3.0, run=False)
            apply(Dial_24.configure, (), {'expanded': False})
        except:
            print "WARNING: failed to restore DialNE named Dial in network self.macroNetwork"
            print_exc()
            Dial_24=None

        self.macroNetwork.freeze()

        ## saving connections for network recluster ##
        if rmsTool_17 is not None and Docking_16 is not None:
            try:
                self.macroNetwork.connectNodes(
                    rmsTool_17, Docking_16, "rmsTool", "rmsTool", blocking=True)
            except:
                print "WARNING: failed to restore connection between rmsTool_17 and Docking_16 in network self.macroNetwork"
        if Read_Molecule_18 is not None and Index_19 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Read_Molecule_18, Index_19, "MolSets", "data", blocking=True)
            except:
                print "WARNING: failed to restore connection between Read_Molecule_18 and Index_19 in network self.macroNetwork"
        if Index_19 is not None and Get_allAtoms_coords_20 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Index_19, Get_allAtoms_coords_20, "data", "objects", blocking=True)
            except:
                print "WARNING: failed to restore connection between Index_19 and Get_allAtoms_coords_20 in network self.macroNetwork"
        if Get_allAtoms_coords_20 is not None and rmsTool_17 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Get_allAtoms_coords_20, rmsTool_17, "attrs", "crds", blocking=True)
            except:
                print "WARNING: failed to restore connection between Get_allAtoms_coords_20 and rmsTool_17 in network self.macroNetwork"
        if Docking_16 is not None and Get_clusterer_21 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Docking_16, Get_clusterer_21, "docking", "objects", blocking=True)
            except:
                print "WARNING: failed to restore connection between Docking_16 and Get_clusterer_21 in network self.macroNetwork"
        if Get_clusterer_21 is not None and Index_22 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Get_clusterer_21, Index_22, "attrs", "data", blocking=True)
            except:
                print "WARNING: failed to restore connection between Get_clusterer_21 and Index_22 in network self.macroNetwork"
        if Index_22 is not None and make_clustering_23 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Index_22, make_clustering_23, "data", "clusterer", blocking=True)
            except:
                print "WARNING: failed to restore connection between Index_22 and make_clustering_23 in network self.macroNetwork"
        if Dial_24 is not None and make_clustering_23 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Dial_24, make_clustering_23, "value", "tolerance", blocking=True)
            except:
                print "WARNING: failed to restore connection between Dial_24 and make_clustering_23 in network self.macroNetwork"
        output_Ports_13 = self.macroNetwork.opNode
        if make_clustering_23 is not None and output_Ports_13 is not None:
            try:
                self.macroNetwork.connectNodes(
                    make_clustering_23, output_Ports_13, "clustering", "new", blocking=True)
            except:
                print "WARNING: failed to restore connection between make_clustering_23 and output_Ports_13 in network self.macroNetwork"
        input_Ports_12 = self.macroNetwork.ipNode
        if input_Ports_12 is not None and Docking_16 is not None:
            try:
                self.macroNetwork.connectNodes(
                    input_Ports_12, Docking_16, "new", "docking_logs", blocking=True)
            except:
                print "WARNING: failed to restore connection between input_Ports_12 and Docking_16 in network self.macroNetwork"
        self.macroNetwork.unfreeze()

        recluster_11.shrink()

        ## reset modifications ##
        recluster_11.resetTags()
        recluster_11.buildOriginalList()



#########################################################################
#
# Date: Nov 2001 Authors: Michel Sanner
#
#    sanner@scripps.edu
#
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Michel Sanner and TSRI
#
#########################################################################

from NetworkEditor.items import NetworkNode
from AutoDockTools.VisionInterface.Adt.dpf_template import dpf_template

class DPFTemplateBrowser(NetworkNode):
    """
    A node that allows the user to browse for a DPF template with the extension .dpf
  
    Input: DPF template file with the extension .dpf
    Output: dpf_template object that contains info about the DPF template file
    """
    
    def __init__(self, name='DPFTemplateBrowser', **kw):
        kw['name'] = name
        apply( NetworkNode.__init__, (self,), kw )

        kw['name'] = name
        apply( NetworkNode.__init__, (self,), kw )
        ip = self.inputPortsDescr
        ip.append(datatype='string', name='dpf_template_file')

        filetypes = [('All supported files', '*.dpf')]

        self.widgetDescr['dpf_template_file'] = {
            'class':'NEEntryWithFileBrowser', 'master':'node', 'width':20,
            'filetypes':filetypes,
            'initialValue':'', 'labelCfg':{'text':'DPF template file: '}
            }

        op = self.outputPortsDescr
        op.append(datatype='dpf_template', name='dpf_template')

        code = """def doit(self, dpf_template_file):
    import os
    from AutoDockTools.VisionInterface.Adt.dpf_template import dpf_template

    dpf_template_file = os.path.abspath(dpf_template_file)

    if not(os.path.exists(dpf_template_file)):
        print "ERROR: DPF template file " + dpf_template_file + " does not exist!"
        return 'stop'

    dpf_template = dpf_template(dpf_template_file)

    self.outputData(dpf_template=dpf_template)
"""
        self.setFunction(code)



#
# Last modified on Thu Mar 11 10:50:58 PST 2004 by lindy
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/EntropiaParser.py,v 1.7 2004/03/11 19:17:04 lindy Exp $
#
#


import string
import types
from AutoDockTools.ResultParser import ResultParser


class EntropiaParser(ResultParser):
    """<class docstring>
    """
    # keywords are the keys of the dictionary used by the
    # ConformationHandler to instantiate a Conformation.
    keywords = ResultParser.keywords + [
        # add keywords here
        ]


    def __init__(self):
        ResultParser.__init__(self)


    def parseline(self, line):
        """Parse the given line and return append a dictionary
        onto self.clist, the superclass-declared list of conformations.
        """
        line_list = string.split(line)
        # make a heuristic decision about which keys to use!!
        if line_list[2] == repr(1.01) or line_list[2][:3] == repr(1.0):
            # version 1.01 Entropia result file
            dict = self._parseStateLineList(line_list, self.result_keys_v101)
        elif float(line_list[9]) == 1.0:
            # version 1.0 Entropia result file
            dict = self._parseStateLineList(line_list)
        else:
            print "Unparsable result file line: %s" % (line)
            return # without doing anything
        self.clist.append(dict)


    result_keys = [        # original version 1.00
        'output_id',
        'data_run_id',
        'dpf_id',
        'creation_dtime',
        'last_update_dtime',
        'ei_version',         # Entropia Interface version
        'ag_version',         # AutoGrid version
        'ad_version',         # AutoDock version
        'run_rank',           # rank of this run in cluster
        'run_number',         # number of this run in dpf
        'cluster_rank',       # rank of this cluster
        'cluster_size',       # number of conformations in this cluster
        'run_size',           # number of runs specified in dpf
        'rseed1',
        'rseed2',
        'rmsd',               # RMSD from reference structure
        'binding_energy',     # estimated free energy of binding
        'docking_energy',     # final docked energy
        'trn_x',              # translation x, y, z
        'trn_y',
        'trn_z',
        'qtn_nx',             # quaternion unit vector x, y, z
        'qtn_ny',
        'qtn_nz',
        'qtn_ang_deg',        # quaternion rotation angle
        'num_torsions',
        'torsion_values']


    result_keys_v101 = [   # for the 1.01 version of the Entropia Interface
        'data_run_id',
        'dpf_id',
        'ei_version',         # Entropia Interface version
        'ag_version',         # AutoGrid version
        'ad_version',         # AutoDock version
        'run_rank',           # rank of this run in cluster
        'run_number',         # number of this run in dpf
        'cluster_rank',       # rank of this cluster
        'cluster_size',       # number of conformations in this cluster
        'run_size',           # number of runs specified in dpf
        'rseed1',
        'rseed2',
        'rmsd',               # RMSD from reference structure
        'binding_energy',     # estimated free energy of binding
        'docking_energy',     # final docked energy
        'trn_x',              # translation x, y, z
        'trn_y',
        'trn_z',
        'qtn_nx',             # quaternion unit vector x, y, z
        'qtn_ny',
        'qtn_nz',
        'qtn_ang_deg',        # quaternion rotation angle
        'num_torsions',
        'torsion_values']


    type_conv = {
        types.IntType    : lambda x: int(x),
        types.FloatType  : lambda x: float(x),
        types.StringType : lambda x: x,
        'PercentType'    : lambda x: float(x[:-1]),
        'TimeType'       : lambda x: x
        }


    field_defn = {
    #    key                : (type, whitespace delimited sub-fields)
        'output_id'         : (types.IntType, 1),
        'data_run_id'       : (types.IntType, 1),
        'dpf_id'            : (types.IntType, 1),
        'creation_dtime'    : ('TimeType', 3),
        'last_update_dtime' : ('TimeType', 3),
        'ei_version'        : (types.FloatType, 1),
        'ag_version'        : (types.FloatType, 1),
        'ad_version'        : (types.FloatType, 1),
        'run_rank'          : (types.IntType, 1),
        'run_number'        : (types.IntType, 1),
        'cluster_rank'      : (types.IntType, 1),
        'cluster_size'      : (types.IntType, 1),
        'run_size'          : (types.IntType, 1),
        'rseed1'            : (types.IntType, 1),
        'rseed2'            : (types.IntType, 1),
        'rmsd'              : (types.FloatType, 1),
        'binding_energy'    : (types.FloatType, 1),
        'docking_energy'    : (types.FloatType, 1),
        'trn_x'             : (types.FloatType, 1),
        'trn_y'             : (types.FloatType, 1),
        'trn_z'             : (types.FloatType, 1),
        'qtn_nx'            : (types.FloatType, 1),
        'qtn_ny'            : (types.FloatType, 1),
        'qtn_nz'            : (types.FloatType, 1),
        'qtn_ang_deg'       : (types.FloatType, 1),
        'num_torsions'      : (types.IntType, 1),
        'torsion_values'    : (types.FloatType, None)
        }



    def _parseStateLineList(self, lineList = None, keys=None):
        """Return a dictionary of values.
        """
        if not keys:
            keys = self.result_keys
        
        # initalize the stateDict with all fields
        stateDict = {}
        for field in self.result_keys:
            stateDict[field] = None

        # now run through the specified fields
        subFldIx = 0
        for field in keys:

            # most fields just get converted in the first case
            if self.field_defn[field][1] == 1:
                stateDict[field] = self.type_conv[
                    self.field_defn[field][0]](lineList[subFldIx])
                subFldIx = subFldIx + 1

            # the time fields have spaces in them; handled here
            elif self.field_defn[field][0] == 'TimeType':
                timeList = []
                for subIx in range( self.field_defn[field][1]):
                    # just append the strings to the timeList
                    timeList.append(lineList[subFldIx])
                    subFldIx = subFldIx + 1
                stateDict[field] = timeList

            # this case handles the variable number of torsions
            elif field == 'torsion_values':
                torsionList = []
                for subIx in range( stateDict['num_torsions']):
                    # loop through the torsion_values
                    torsionList.append( self.type_conv[
                        self.field_defn[field][0]](lineList[subFldIx]))
                    subFldIx = subFldIx + 1
                stateDict[field] = torsionList

        # make sure there are no left over fields
        assert len(lineList) == subFldIx
        return stateDict












#
#
#
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/Tests/test_dlg_filters.py,v 1.4 2010/05/10 23:53:21 annao Exp $
#
# $Id: test_dlg_filters.py,v 1.4 2010/05/10 23:53:21 annao Exp $
#
#
#
# 
#

import unittest, os, sys
from AutoDockTools.DlgFilters import Filter, EnergyFilter, ClusterSizeFilter, ClusterPercentageFilter,\
                                     EnergyClusterSizeFilter, BestEnergyInLargestCluster, \
                                     EnergyPlusBestEnergyInLargestCluster, LigandEfficiencyFilter, \
                                     InteractionFilter


class FilterBaseTests(unittest.TestCase):
    def setUp(self):
        """
        instantiate an EnergyFilter
        """
        filter = Filter()
        self.assertEquals(filter.__class__, Filter)

        
class EnergyFilterTests(FilterBaseTests):

    def test_PassingEnergyFilter(self):
        """
        lowest energy in dlg -11.14 passes compared to -11 
        """
        self.ef = EnergyFilter(-11)
        self.assertEqual(self.ef.filter("ind4.1.1.DLG"), True)

    def test_PassingEnergyFilter2(self):
        """
        lowest energy in dlg -11.14 passes compared to -11.1 
        """
        self.ef = EnergyFilter(-11)
        self.assertEqual(self.ef.filter("ind4.1.1.DLG"), True)


    def test_FailingEnergyFilter(self):
        """
        lowest energy in dlg -11.14 fails compared to -12 
        """
        self.ef = EnergyFilter(-12)
        self.assertEqual(self.ef.filter("ind4.1.1.DLG"), False)


        
class ClusterSizeFilterTests(FilterBaseTests):

    def test_PassingClusterSizeFilter(self):
        """
        largest cluster size in dlg 8 passes compared to 6
        """
        self.csf = ClusterSizeFilter(cluster_size=6)
        self.assertEqual(self.csf.filter("ind4.1.1.DLG"), True)


    def test_PassingClusterSizeFilter0(self):
        """
        largest cluster size in dlg 8 passes compared to 0
        """
        self.csf = ClusterSizeFilter(cluster_size=0)
        self.assertEqual(self.csf.filter("ind4.1.1.DLG"), True)


    def test_FailingClusterSizeFilter(self):
        """
        largest cluster size in dlg 8 fails compared to 9
        """
        self.csf = ClusterSizeFilter(cluster_size=9)
        self.assertEqual(self.csf.filter("ind4.1.1.DLG"), False)


        
class ClusterPercentageFilterTests(FilterBaseTests):

    def test_PassingClusterPercentageFilterTests(self):
        """
        percentage in cluster in dlg 80 passes compared to 60
        """
        self.csf = ClusterPercentageFilter(percentage=60)
        self.assertEqual(self.csf.filter("ind4.1.1.DLG"), True)


    def test_PassingClusterPercentageFilterTests2(self):
        """
        percentage in cluster in dlg 80 passes compared to 80
        """
        self.csf = ClusterPercentageFilter(percentage=80)
        self.assertEqual(self.csf.filter("ind4.1.1.DLG"), True)


    def test_FailingClusterPercentageFilterTests(self):
        """
        percentage in cluster in dlg 80 fails compared to 90
        """
        self.csf = ClusterPercentageFilter(percentage=90)
        self.assertEqual(self.csf.filter("ind4.1.1.DLG"), False)


class EnergyClusterSizeFilterTests(FilterBaseTests):

    def test_PassingEnergyClusterSizeFilter(self):
        """
        energy -11 and cluster_size 6 pass compared to -11.14 and 8 in dlg 
        """
        self.ecsf = EnergyClusterSizeFilter(energy=-11, cluster_size=6)
        self.assertEqual(self.ecsf.filter("ind4.1.1.DLG"), True)


    def test_FailingEnergyClusterSizeFilter(self):
        """
        energy -11 and cluster_size 9 fail compared to -11.14 and 8 in dlg 
        """
        self.ecsf = EnergyClusterSizeFilter(energy=-11, cluster_size=9)
        self.assertEqual(self.ecsf.filter("ind4.1.1.DLG"), False)


    def test_FailingEnergyClusterSizeFilter2(self):
        """
        energy -12 and cluster_size 6 fail compared to -11.14 and 8 in dlg 
        """
        self.ecsf = EnergyClusterSizeFilter(energy=-12, cluster_size=6)
        self.assertEqual(self.ecsf.filter("ind4.1.1.DLG"), False)



class BestEnergyInLargestClusterTests(FilterBaseTests):

    def test_PassingBestEnergyInLargestCluster(self):
        """
        cluster containing best energy conformation is also the largest cluster 
        """
        self.ecsf = BestEnergyInLargestCluster()
        self.assertEqual(self.ecsf.filter("ind4.1.1.DLG"), True)


    def test_FailingBestEnergyInLargestCluster(self):
        """
        cluster containing best energy conformation is NOT also the largest cluster 
        """
        self.ecsf = BestEnergyInLargestCluster()
        self.assertEqual(self.ecsf.filter("0033.dlg"), False)



class LigandEfficiencyFilterTests(FilterBaseTests):

    def test_PassingLigandEfficiencyFilter(self):
        """
        LigandEfficiency is the best overall energy/number of atoms in the ligand 
        """
        self.ecsf = LigandEfficiencyFilter(-0.2) 
        self.assertEqual(self.ecsf.filter("ind4.1.1.DLG"), True)


    def test_FailingLigandEfficiencyFilter(self):
        """
        cluster containing best energy conformation is NOT also the largest cluster 
        """
        self.ecsf2 = LigandEfficiencyFilter(-0.25)
        #-0.22918367 when 4 hydrogens were included in the count , -0.2476 without them
        self.assertEqual(self.ecsf2.filter("ind4.1.1.DLG"), False)


class InteractionFilterTests(FilterBaseTests):

    def test_PassingInteractionFilter(self):
        """
        two atoms interact if the distance between them is less than the sum
        of their vdw radii
        """
        self.intF = InteractionFilter("hsg1.pdbqt")
        self.assertEqual(self.intF.filter("ind4.1.1.DLG"), 34)


    def test_FailingInteractionFilter(self):
        """
        no interactions between docked ligand and hsg1.pdbqt
        """
        self.intF = InteractionFilter("1dwd_rec.pdbqt")
        self.assertEqual(self.intF.filter("ind4.1.1.DLG"), 0)




if __name__ == '__main__':
    #unittest.main()
    test_cases = [
        'EnergyFilterTests',
        'ClusterSizeFilterTests',
        'ClusterPercentageFilterTests',
        'EnergyClusterSizeFilterTests',
        'BestEnergyInLargestClusterTests',
        'LigandEfficiencyFilterTests',
        'InteractionFilterTests',
            ]
    unittest.main( argv=([__name__ ,] + test_cases) )


    



#
# 
#
# $Id: lib_parameter_file_writer.py,v 1.4 2004/08/25 20:44:33 rhuey Exp $
#

import os, string, glob
from MolKit import Read
from AutoDockTools.GridParameters import GridParameters, grid_parameter_list
from AutoDockTools.DockingParameters import DockingParameters
from AutoDockTools.DockingParameters import genetic_algorithm_list, \
                genetic_algorithm_local_search_list, local_search_list,\
                simulated_annealing_list



class LibraryGpfWriter:

    def __init__(self, gpffile, extension='pdbq', err_file="write_lib_gpf_errors", 
                           prefix='',alltypes=None, extratypes_dict={}, verbose=0):
        self.verbose = verbose
        if verbose: print "self.verbose = ", verbose
        self.extratypes_dict = extratypes_dict
        self.setup(gpffile)
        self.alltypes = alltypes
        if self.alltypes is None:
            self.alltypes = self.gettypes(extension)
        self.prefix = prefix
        #real element, Rii, epsii
        #eg {X:['Cl', 4.09, .02345]}
        #WHAT errors should be captured
        #self.error_file = open(err_file, 'w')
    

    def setup(self,gpffile):
        self.gpffile = gpffile
        self.gpo = GridParameters() 
        self.gpo.read(gpffile)
        if len(self.extratypes_dict):
            print "update each type in extratypes here"
        #????RENAME extratype in receptor and write new output file here?


    def set_receptor(self, receptor_filename):
        self.gpo.set_receptor(receptor_filename)
        ty


    def gettypes(self, extension, name=''):
        typeDict = {}
        key = name + '*.' + extension
        ligandfilenames = glob.glob(key)
        if self.verbose:
            print "processing ", len(ligandfilenames), " files matching ", key
        for ligand_file in ligandfilenames:
            m = Read(ligand_file)[0]
            for a in m.allAtoms:
                typeDict[a.autodock_element] = 1
            del(m)
        alltypes = typeDict.keys()
        return alltypes


    def write(self, gpo):
        #set types in groups of 6 + write
        outputlist = []
        number_of_files = len(self.alltypes)/6 + 1
        ctr = 0
        last = 6
        for i in range(number_of_files):
            if i == number_of_files-1:
                current_types = self.alltypes[ctr*6:]
            elif last>len(self.alltypes):
                current_types = self.alltypes[ctr*6:]
            else:
                current_types = self.alltypes[ctr*6:last]
            gpo['types']['value'] =  string.join(current_types,'')
            if not gpo.receptor_stem:
                gpo.receptor_stem = os.path.splitext(gpo['receptor']['value'])[0]
            outputfilename = self.prefix + gpo.receptor_stem + '_'+ str(ctr) + '_library.gpf'
            gpo.write(outputfilename, grid_parameter_list)
            ctr = ctr + 1
            last = last + 6
            outputlist.append(outputfilename)
        return outputlist

#what about checking that the box is big enough for each ligand??



class LibraryDpfWriter:


    def __init__(self, dpffile, extension='pdbq', \
                    err_file="write_lib_dpf_errors", 
                    prefix='', verbose=0):
        self.verbose = verbose
        if verbose: print "self.verbose = ", verbose
        self.prefix = prefix
        self.setup(dpffile)
        self.parm_list_dict = {}
        self.parm_list_dict['GALS'] = genetic_algorithm_local_search_list
        self.parm_list_dict['GA'] = genetic_algorithm_list
        self.parm_list_dict['LS'] = local_search_list
        self.parm_list_dict['SA'] = simulated_annealing_list
        self.ligandfilenames = []
        self.extension = extension
        self.error_file = open(err_file, 'w')


    def setup(self, dpffile):
        self.dpffile = dpffile
        self.dpo = DockingParameters() 
        self.dpo.read(dpffile)


    def getligands(self, extension, name=''):
        typeDict = {}
        key = name + '*.' + extension
        self.ligandfilenames = glob.glob(key)
        return self.ligandfilenames


    def write(self, dpo, style='GALS'):
        #one file per ligand
        dpffiles = []
        receptor_stem = self.dpo.receptor_stem
        parm_list = self.parm_list_dict[style]
        if not len(self.ligandfilenames):
            self.getligands(self.extension)
        #print "len(self.ligandfilenames)=", len(self.ligandfilenames)
        for ligand_file in self.ligandfilenames:
            #get the types 
            typeDict = {}
            m = Read(ligand_file)[0]
            for a in m.allAtoms:
                typeDict[a.autodock_element] = 1
            type_list = typeDict.keys()
            #check that there is a map for each type
            ok = 1
            for t in type_list:
                mapfile = receptor_stem + '.' + t + '.map'
                try:
                    assert os.path.exists(mapfile)
                except:
                    ok = 0
                    ostr = ligand_file + " missing map " + t + "\n"
                    self.error_file.write(ostr)
                    break  #try to continue 'for' statement with next filename
            #update dpo with ligand specific values
            if not ok:
                if self.verbose:
                    print "problem with ", ligand_file
                continue
            types = string.join(type_list,'')
            self.dpo['move']['value'] = ligand_file
            if self.verbose: print "set types to ", types
            self.dpo['types']['value'] = types
            #CAUTION: dpo['torsdof']['value'] is [0,0.3113]
            self.dpo['torsdof']['value'][0] = m.TORSDOF
            if hasattr(m, 'ndihe'):
                ndihe = m.ndihe
            elif hasattr(m, 'torscount'):
                ndihe = m.torscount
            elif hasattr(m, 'torTree'):
                ndihe = len(m.torTree.torsionMap)
            else:
                msg = ligand_file + " is not properly formatted: no torsions!"
                raise AttributeError, msg
            self.dpo['ndihe']['value'] = ndihe
            outputfilename = self.prefix + m.name + "_" + style + ".dpf"
            if self.verbose: print "writing ", outputfilename
            self.dpo.write(outputfilename, parm_list)
            dpffiles.append(outputfilename)
        return dpffiles

            




#!/usr/bin/env python
#
# 
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/Utilities24/prepare_ligand_dict.py,v 1.2 2007/10/08 18:12:45 rhuey Exp $
#

import os
from MolKit import Read


class LigandDictionaryMaker:
    """Accept a <ligand>.pdbq and <receptor>.pdbqs and create
    <ligand>_<receptor>.dpf
    """

    def __init__(self, filename="ligand_dict.py", verbose = None):
        self.verbose = verbose
        self.dict = {}
        self.dict['atom_types'] = {}
        self.dict['rbonds'] = {}
        self.dict['zero_charge'] = {}
        self.filename = filename


    def write_ligand_filename(self, ligandfilename):
        ligand = Read(ligandfilename)[0]
        self.write_ligand(ligand)


    def write_ligand(self, ligand):
        if not os.path.exists(self.filename):
            fptr = open(self.filename, 'a')
            ostr = "summary = d = {}\n"
            fptr.write(ostr)
        else:
            fptr = open(self.filename, 'a')
        type_dict = {}
        for a in ligand.allAtoms:
            type_dict[a.autodock_element] = 1
        atom_types = type_dict.keys()
        atom_types.sort()
        ostr = "d['" + ligand.name +"'] = {"
        ostr = ostr + "'atom_types': [" 
        for t in atom_types[:-1]:
            ostr = ostr + "'%s', "%t
        ostr = ostr + "'%s' "%atom_types[-1]
        ostr = ostr + "],\n\t\t\t\t'rbonds':" + str(len(ligand.torTree.torsionMap))
        ostr = ostr + ",\n\t\t\t\t'zero_charge' : ["
        zc_ats = ligand.allAtoms.get(lambda x: x.charge==0)
        for at in zc_ats:
            ostr = ostr + "'%s', "%at.name
        ostr = ostr + "],\n\t\t\t\t}\n"
        fptr.write(ostr)
        fptr.close()

        #to write the dictionary inside out
        #if not os.path.exists(self.filename):
        #    fptr = open(self.filename, 'a')
        #    ostr = "summary = d = {'atom_types':{}, 'rbonds':{}, 'zero_charge':{}}\n"
        #ostr = "d['atom_types']['" + ligand.name +"'] = ["
        #for t in atom_types[:-1]:
        #    ostr = ostr + "'%s', "%t
        #ostr = ostr + "'%s' "%atom_types[-1]
        #ostr = ostr + "]\nd['rbonds']['" + ligand.name + "'] = " + str(len(ligand.torTree.torsionMap))
        #ostr = ostr + "\nd['zero_charge']['" + ligand.name + "'] =  ["
        #zc_ats = ligand.allAtoms.get(lambda x: x.charge==0)
        #for at in zc_ats:
        #    ostr = ostr + "'%s',"%at.name
        #ostr = ostr + "]\n"
        #fptr.write(ostr)
        #fptr.close()

 

def usage():
    print "Usage: prepare_ligand_dict.py -l ligand_filename -d ligand_dict_filename"
    print
    print "Optional parameters:"
    print "    [-d ligand_dict_filename]"
    print "    [-v] verbose output"
    print
    print "Write a python dictionary 'summary' comprised of dictionaries of atom_types, rbonds and zero_charge atoms with an entry for each ligand filename."
    print
    print "   The filename will be ligand_dict.py.  "
    print "This may be overridden using the -d flag."

    
if __name__ == '__main__':
    import getopt
    import sys

    try:
        opt_list, args = getopt.getopt(sys.argv[1:], 'hvl:d:')
    except getopt.GetoptError, msg:
        print 'prepare_ligand_dict.py: %s' % msg
        usage()
        sys.exit(2)

    ligand_filename = None
    ligand_dict_filename = None
    verbose = None
    for o, a in opt_list:
        if verbose: print "o=", o, ' a=', a
        if o in ('-v', '--v'):
            verbose = 1
            if verbose: print 'verbose output'
        if o in ('-l', '--l'):
            ligand_filename = a
            if verbose: print 'ligand_filename =', ligand_filename
        if o in ('-d', '--d'):
            ligand_dict_filename = a
            if verbose: print 'ligand_dict_filename =', ligand_dict_filename
        if o in ('-h', '--'):
            usage()
            sys.exit()


    if not ligand_filename:
        print "prepare_ligand_dict.py: ligand filename must be specified."
        usage()
        sys.exit()

    ldm = LigandDictionaryMaker(filename=ligand_dict_filename, verbose=verbose)
    ldm.write_ligand_filename( ligand_filename)
    
#prepare_ligand_dict.py -l indinavir.pdbq -d hiv_ligands_dict.py"




#!/usr/bin/env python
#
# $Id: write_vs_hits.py,v 1.1 2009/01/09 20:40:32 rhuey Exp $
#

import os

from AutoDockTools.Docking import Docking

if __name__ == '__main__':
    import sys
    import getopt


    def usage():
        """Print helpful, accurate usage statement to stdout."""
        print "Usage: write_vs_hits.py -s summary_filename -d path_to_dockings"
        print
        print "    Write result file of top conformations from VS."
        print
        print "    Required parameters:"
        print "         -s name of summary file, eg 'summary_2.0.sort', produced in exercise10 of VS"
        print "         -p path_to_dockings containing files listed in summary file"
        print "    Optional parameters:"
        print "        [-f pdbqt_filename] file to create. Default is 'vs_results.pdbqt'"
        print "        [-A]             output ATOM and HETATM records only "
        print "        [-v]             verbose output"
        print "        [-D]             debugging output"


    # process command arguments
    try:
        opt_list, args = getopt.getopt(sys.argv[1:], 's:p:f:Avh')
    except getopt.GetoptError, msg:
        print 'write_vs_hits.py: %s' %msg
        usage()
        sys.exit(2)

    # initialize required parameters
    #-s: summary_filename
    summary_filename =  None
    #-p: path_to_dockings
    path_to_dockings =  None

    # optional parameters
    #-f: pdbqtfilename
    pdbqt_filename =  "vs_results.pdbqt"
    verbose = None
    atom_records_only = False

    for o, a in opt_list:
        if o in ('-s', '--s'):
            summary_filename = a
            if verbose: print "set summary_filename  %s" % summary_filename
        if o in ('-p', '--p'):
            path_to_dockings = a
            if verbose: print "set path_to_dockings  %s" % path_to_dockings
        if o in ('-f', '--f'):
            pdbqt_filename = a
            if verbose: print "set pdbqt_filename to  %s" % pdbqt_filename
        if o in ('-A', '--A'):
            atom_records_only = True
            if verbose: print "set print ATOM and HETATM records only to %s" % atom_records_only
        if o in ('-v', '--v'):
            if verbose: print "set verbose to  %s" % verbose
        if o in ('-h', '--'):
            usage()
            sys.exit(2)

    # make sure summary_filename and path_to_dockings were specified
    if not summary_filename:
        print 'write_vs_hits: summary_filename must be specified.'
        usage()
    if not path_to_dockings:
        print 'write_vs_hits: path_to_dockings must be specified.'
        usage()
        sys.exit(2)


    # make sure summary_filename exists
    try:
        os.stat(summary_filename)
    except OSError, msg:
        print "write_vs_hits: %s: %s",  msg.strerror, msg.filename
        sys.exit()

    fileptr = open(summary_filename, 'r')
    all_lines = fileptr.readlines()
    fileptr.close()
    if not len(all_lines): 
        print "write_vs_hits: no useable lines in %s", summary_filename
        sys.exit()
    #ctr will be recorded in the residue field (18-20, 1-based)
    ctr = 1
    optr = open(pdbqt_filename, 'w')
    for line in all_lines:
        #sample line to use:
        #ZINC00057384_x1hpv/ZINC00057384_x1hpv,  20,  4, 10, -9.0900....
        #skip the header line
        if line.find('lowestEnergy')>-1: 
            #lowestEnergy dlgfn     #runs #cl #LEC    LE      rmsd     largestCl_dlgfn ...
            continue
        #write line from summary_filename
        ostr = "REMARK %s"%line
        optr.write(ostr)
        #find the docking log filename
        ll = line.split()
        fn = ll[0].strip()[:-1]
        dlgFN = path_to_dockings + "/" + fn +".dlg"
        #create a docking
        d = Docking()
        d.readDlg(dlgFN)
        #set ligand to lowest energy conformation LE
        cluD = d.clusterer.clustering_dict
        rms_tol = cluD.keys()[0]
        LE = cluD[rms_tol][0][0]
        d.ch.set_conformation(LE)
        #get coordinates of LE conformation
        crds = d.ligMol.allAtoms.coords[:]
        #use the parser to get newlines to output
        lines_to_print = d.ligMol.parser.write_with_new_coords(crds)
        #edit these lines, adding new line + changing the RES field to current count
        for nl in lines_to_print: 
            if nl[-1]!="\n":
                nl += "\n"
            if atom_records_only:
                if nl.find("ATOM")!=0 and nl.find("HETA")!=0: 
                    #skip lines of ligand keywords, eg ROOT
                    continue
            #replace the RES field with current count
            nl = nl[:17] + "%3s"%ctr + nl[20:]
            optr.write(nl)
        if verbose: print "onto next vs hit line"
        ctr+=1
    optr.close()
# To execute this command type:
# write_vs_hits.py -s summary_filename -o pdbqt_filename -v




## Automatically adapted for numpy.oldnumeric Jul 23, 2007 by 

#
#
#  $Id: test_AD4flex.py,v 1.2 2010/05/26 21:45:39 annao Exp $
#
#

import unittest, glob, os, sys
from string import strip, find, split
import time
from MolKit.molecule import Atom

mv = None
ct = 0
totalCt = 6


class AD4flex_BaseTests(unittest.TestCase):
    """
    setUp + tearDown form a fixture: working environment for the testing code
    """
    
        
    def startViewer(self):
        global mv
        #print 'in test_AD startViewer'
        if mv is None:
            from MolKit import Read
            import Tkinter
            from Pmv.moleculeViewer import MoleculeViewer
            mv = MoleculeViewer(trapExceptions=False)
            mv.loadModule('autoflex4Commands', 'AutoDockTools')
            mv.loadModule('deleteCommands', 'Pmv')
            mv.loadModule('selectionCommands', 'Pmv')
            #change warningMsg format
            mv.setUserPreference(('warningMsgFormat', 'printed'), log = 0)
        self.mv = mv


    def setUp(self):
        """
        clean-up
        """
        if not hasattr(self, 'mv'):
            self.startViewer()
        for m in self.mv.Mols:
            self.mv.deleteMol(m)


    def tearDown(self):
        """
        clean-up
        """
        #print 'in flex tearDown'
        global ct, totalCt
        #reset flexDict object
        self.mv.flexDict = {}
        #delete any molecules left due to errors
        for m in self.mv.Mols:
            self.mv.deleteMol(m)
        ct = ct + 1
        #print 'ct =', ct
        if ct==totalCt:
            print 'destroying mv'
            self.mv.Exit(0)
            del self.mv       
    
        

class AD4flex_readflexTests(AD4flex_BaseTests):
    
    
    def test_flex4_read_macro_mol(self):
        """readflexTests: check that reading a macromol sets expected flexdict items
        """
        filename = '1ebg_rec.pdbqt'
        self.mv.AD4flex_readMacro(macroFile=filename)
        self.assertEqual(self.mv.flexDict['macrofilename'], filename)
        self.assertEqual(self.mv.flexDict['macroname'], '1ebg_rec')
        self.assertEqual(self.mv.flexDict['macromol'], self.mv.Mols[0])
    

    def test_flex4_choose_macro_mol_name(self):
        """readflexTests: check that choosing a macro sets expected flexDict items
        """
        filename = '1ebg_rec.pdbqt'
        self.mv.readMolecule(filename)
        macro_name = self.mv.Mols[0].name
        self.mv.AD4flex_chooseMacro(macro_name)
        self.assertEqual(self.mv.flexDict['macroname'], macro_name)
        self.assertEqual(self.mv.flexDict['macromol'], self.mv.Mols[0])
        self.assertEqual(self.mv.flexDict['macrofilename'], filename)


    #next 2 tests were added after a bug was fixed    
    def test_flex4_read_macro_delete_it(self):
        """readflexTests: check onRemoveObjFromViewer bug is fixed #1:
                AD4flex_readMacro, delete macro and check flexdict items
        """
        filename = '1ebg_rec.pdbqt'
        self.mv.AD4flex_readMacro(macroFile=filename)
        self.assertEqual(self.mv.flexDict['macrofilename'], filename)
        self.assertEqual(self.mv.flexDict['macroname'], '1ebg_rec')
        self.assertEqual(self.mv.flexDict['macromol'], self.mv.Mols[0])
        self.mv.deleteMol("1ebg_rec")
        self.assertEqual(self.mv.flexDict, {})
    

    def test_flex4_read_ind_read_macro_delete_ind(self):
        """readflexTests: check onRemoveObjFromViewer bug is fixed #2:
                read ind,  AD4flex_readMacro, delete ind and check flexdict items
        """
        self.mv.readMolecule('ind.pdbqt')
        filename = '1ebg_rec.pdbqt'
        self.mv.AD4flex_readMacro(macroFile=filename)
        self.assertEqual(self.mv.flexDict['macrofilename'], filename)
        self.assertEqual(self.mv.flexDict['macroname'], '1ebg_rec')
        self.assertEqual(self.mv.flexDict['macromol'], self.mv.Mols[1])
        self.mv.deleteMol("ind")
        self.assertEqual(self.mv.flexDict['macrofilename'], filename)
        self.assertEqual(self.mv.flexDict['macroname'], '1ebg_rec')
        self.assertEqual(self.mv.flexDict['macromol'], self.mv.Mols[0])
    
 

class AD4flex_formatting_flexResTests(AD4flex_BaseTests):

    def test_flex4_formatting_arg8(self):
        """flex4_formatting_arg8: processing both arg8 residues produces expected result files
        """
        self.mv.readMolecule('hsg1.pdbqt', ask=0, parser=None)
        self.mv.AD4flex_chooseMacro("hsg1")
        self.mv.AD4flex_setResidues("::ARG8")
        self.mv.ADflex_setBondRotatableFlag("hsg1:B:ARG8:CA,CB;", 0)
        self.mv.ADflex_setBondRotatableFlag("hsg1:A:ARG8:CA,CB;", 0)
        bnds = self.mv.Mols[0].chains.residues.get("ARG8").atoms.bonds[0]
        sum = 0
        possibleCt = bnds.possibleTors.count(1)
        self.assertEqual(possibleCt, 14)
        activeCt = bnds.activeTors.count(1)
        self.assertEqual(activeCt, 6)
        flex_filename = 'temp_FLEX.pdbqt'
        rigid_filename = 'temp_RIGID.pdbqt'
        for fn in [flex_filename, rigid_filename]:
            if os.path.exists(fn):
                cmd = 'rm -f ' + fn
                os.system(cmd)

        self.mv.AD4flex_writeFlexFile(flex_filename)
        self.mv.AD4flex_writeRigidFile(rigid_filename)
        for testfile,reffile in zip([flex_filename, rigid_filename],\
                ['ref_hsg1_flex.pdbqt', 'ref_hsg1_rigid.pdbqt']):
            testptr = open(testfile) 
            testlines = testptr.readlines()
            refptr = open(reffile)
            reflines = refptr.readlines()
            for refline, testline in zip(reflines, testlines):
                self.assertEqual(refline, testline)
        

    def test_flex4_formatting_TRP(self):
        """ flex4_formatting_TRP: processing a single TRP residue gives expected number of rotatable bonds...
        """
        self.mv.readMolecule('hsg1.pdbqt', ask=0, parser=None)
        self.mv.AD4flex_chooseMacro("hsg1")
        #try to format TRP6 in chain A
        self.mv.AD4flex_setResidues(":A:6")
        self.mv.ADflex_setBondRotatableFlag(":A::CA,CB;", 0)
        bnds = self.mv.Mols.chains.residues.get("6").atoms.bonds[0]
        possibleCt = bnds.possibleTors.count(1)
        self.assertEqual(possibleCt, 4)
        activeCt = bnds.activeTors.count(1)
        self.assertEqual(activeCt, 3)



###class AD4flex_hingeTests(AD4flex_BaseTests):


###    def test_flex4_met46_lys55_hinge_log(self):
###        """format hinge met46_lys55: __call__ gives expected hinge
###        """
###        cmd = self.mv.AD4flex_setHinge
###        cmd.selectionBase.set("")
###        cmd.atomOne = None
###        cmd.atomTwo = None
###        cmd.atoms = []
###        self.mv.AD4flex_readMacro('./1hvr_rec.pdbqt', log=0)
###        self.mv.AD4flex_setHinge(("1hvr_rec:A:MET46:CA", "1hvr_rec:A:LYS55:CA"), "1hvr_rec:A:MET46:C;1hvr_rec:A:MET46:O;1hvr_rec:A:MET46:CB;1hvr_rec:A:MET46:CG;1hvr_rec:A:MET46:SD;1hvr_rec:A:MET46:CE;1hvr_rec:A:ILE47:N;1hvr_rec:A:ILE47:CA;1hvr_rec:A:ILE47:C;1hvr_rec:A:ILE47:O;1hvr_rec:A:ILE47:CB;1hvr_rec:A:ILE47:CG1;1hvr_rec:A:ILE47:CG2;1hvr_rec:A:ILE47:CD1;1hvr_rec:A:ILE47:H;1hvr_rec:A:GLY48:N;1hvr_rec:A:GLY48:CA;1hvr_rec:A:GLY48:C;1hvr_rec:A:GLY48:O;1hvr_rec:A:GLY48:H;1hvr_rec:A:GLY49:N;1hvr_rec:A:GLY49:CA;1hvr_rec:A:GLY49:C;1hvr_rec:A:GLY49:O;1hvr_rec:A:GLY49:H;1hvr_rec:A:ILE50:N;1hvr_rec:A:ILE50:CA;1hvr_rec:A:ILE50:C;1hvr_rec:A:ILE50:O;1hvr_rec:A:ILE50:CB;1hvr_rec:A:ILE50:CG1;1hvr_rec:A:ILE50:CG2;1hvr_rec:A:ILE50:CD1;1hvr_rec:A:ILE50:H;1hvr_rec:A:GLY51:N;1hvr_rec:A:GLY51:CA;1hvr_rec:A:GLY51:C;1hvr_rec:A:GLY51:O;1hvr_rec:A:GLY51:H;1hvr_rec:A:GLY52:N;1hvr_rec:A:GLY52:CA;1hvr_rec:A:GLY52:C;1hvr_rec:A:GLY52:O;1hvr_rec:A:GLY52:H;1hvr_rec:A:PHE53:N;1hvr_rec:A:PHE53:CA;1hvr_rec:A:PHE53:C;1hvr_rec:A:PHE53:O;1hvr_rec:A:PHE53:CB;1hvr_rec:A:PHE53:CG;1hvr_rec:A:PHE53:CD1;1hvr_rec:A:PHE53:CD2;1hvr_rec:A:PHE53:CE1;1hvr_rec:A:PHE53:CE2;1hvr_rec:A:PHE53:CZ;1hvr_rec:A:PHE53:H;1hvr_rec:A:ILE54:N;1hvr_rec:A:ILE54:CA;1hvr_rec:A:ILE54:C;1hvr_rec:A:ILE54:O;1hvr_rec:A:ILE54:CB;1hvr_rec:A:ILE54:CG1;1hvr_rec:A:ILE54:CG2;1hvr_rec:A:ILE54:CD1;1hvr_rec:A:ILE54:H;1hvr_rec:A:LYS55:N;1hvr_rec:A:LYS55:H;")
###        hinge_list = self.mv.flexDict['hinge_list']
###        self.assertEqual(len(hinge_list), 1)
###        hinge = hinge_list[0]
###        self.assertEqual(len(hinge), 2)
###        (atomOne, atomTwo), atoms = hinge
###        self.assertEqual(atomOne.full_name(), '1hvr_rec:A:MET46:CA')
###        self.assertEqual(atomTwo.full_name(), '1hvr_rec:A:LYS55:CA')
###        self.assertEqual(len(atoms), 67)


###    def test_flex4_formatting_met46_lys55_hinge_with_saved_sets(self):
###        """format hinge met46_lys55: formatting with saved_sets gives expected hinge
###        """
###        cmd = self.mv.AD4flex_setHinge
###        cmd.selectionBase.set("")
###        cmd.atomOne = None
###        cmd.atomTwo = None
###        cmd.atoms = []
###        self.mv.readMolecule('1hvr_rec.pdbqt', ask=0, parser=None)
###        self.mv.saveSet("1hvr_rec:A:MET46,LYS55:CA", 'hinge1')
###        self.mv.saveSet("1hvr_rec:A:ILE54:N;1hvr_rec:A:ILE54:CA;1hvr_rec:A:ILE54:C;1hvr_rec:A:ILE54:O;1hvr_rec:A:ILE54:CB;1hvr_rec:A:ILE54:CG1;1hvr_rec:A:ILE54:CG2;1hvr_rec:A:ILE54:CD1;1hvr_rec:A:ILE54:H;1hvr_rec:A:PHE53:N;1hvr_rec:A:PHE53:CA;1hvr_rec:A:PHE53:C;1hvr_rec:A:PHE53:O;1hvr_rec:A:PHE53:CB;1hvr_rec:A:PHE53:CG;1hvr_rec:A:PHE53:CD1;1hvr_rec:A:PHE53:CD2;1hvr_rec:A:PHE53:CE1;1hvr_rec:A:PHE53:CE2;1hvr_rec:A:PHE53:CZ;1hvr_rec:A:PHE53:H;1hvr_rec:A:GLY52:N;1hvr_rec:A:GLY52:CA;1hvr_rec:A:GLY52:C;1hvr_rec:A:GLY52:O;1hvr_rec:A:GLY52:H;1hvr_rec:A:GLY51:N;1hvr_rec:A:GLY51:CA;1hvr_rec:A:GLY51:C;1hvr_rec:A:GLY51:O;1hvr_rec:A:GLY51:H;1hvr_rec:A:ILE50:N;1hvr_rec:A:ILE50:CA;1hvr_rec:A:ILE50:C;1hvr_rec:A:ILE50:O;1hvr_rec:A:ILE50:CB;1hvr_rec:A:ILE50:CG1;1hvr_rec:A:ILE50:CG2;1hvr_rec:A:ILE50:CD1;1hvr_rec:A:ILE50:H;1hvr_rec:A:GLY49:N;1hvr_rec:A:GLY49:CA;1hvr_rec:A:GLY49:C;1hvr_rec:A:GLY49:O;1hvr_rec:A:GLY49:H;1hvr_rec:A:GLY48:N;1hvr_rec:A:GLY48:CA;1hvr_rec:A:GLY48:C;1hvr_rec:A:GLY48:O;1hvr_rec:A:GLY48:H;1hvr_rec:A:ILE47:N;1hvr_rec:A:ILE47:CA;1hvr_rec:A:ILE47:C;1hvr_rec:A:ILE47:O;1hvr_rec:A:ILE47:CB;1hvr_rec:A:ILE47:CG1;1hvr_rec:A:ILE47:CG2;1hvr_rec:A:ILE47:CD1;1hvr_rec:A:ILE47:H;1hvr_rec:A:LYS55:N;1hvr_rec:A:LYS55:H;1hvr_rec:A:MET46:C;1hvr_rec:A:MET46:O", 'h1', log=0, comments='No description')
###        self.mv.AD4flex_setHinge(self.mv.sets['hinge1'],self.mv.sets['h1']) 
###        hinge_list = self.mv.flexDict['hinge_list']
###        self.assertEqual(len(hinge_list), 1)
###        hinge = hinge_list[0]
###        self.assertEqual(len(hinge), 2)
###        (atomOne, atomTwo), atoms = hinge
###        self.assertEqual(atomOne.full_name(), '1hvr_rec:A:MET46:CA')
###        self.assertEqual(atomTwo.full_name(), '1hvr_rec:A:LYS55:CA')
###        self.assertEqual(len(atoms), 63)



###    def test_flex4_formatting_met46_lys55_hinge_via_gui(self):
###        """hinge met46_lys55: formatting with saved_sets gives expected hinge 
###        """
###        cmd = self.mv.AD4flex_setHinge
###        cmd.selectionBase.set("")
###        cmd.atomOne = None
###        cmd.atomTwo = None
###        cmd.atoms = []
###        self.mv.readMolecule('1hvr_rec.pdbqt', ask=0, parser=None)
###        #select the hinge atoms
###        self.mv.select("1hvr_rec:A:MET46,LYS55:CA")
###        cmd = self.mv.AD4flex_setHinge
###        cmd.selectHingeMethod.set('cursel')
###        cmd.updateHinge()
###        cmd.selectionBase.set('between')
###        cmd.updateBase()
###        cmd.setHinge_cb()
###        hinge_list = self.mv.flexDict['hinge_list']
###        self.assertEqual(len(hinge_list), 1)
###        hinge = hinge_list[0]
###        self.assertEqual(len(hinge), 2)
###        (atomOne, atomTwo), atoms = hinge
###        self.assertEqual(atomOne.full_name(), '1hvr_rec:A:MET46:CA')
###        self.assertEqual(atomTwo.full_name(), '1hvr_rec:A:LYS55:CA')
###        self.assertEqual(len(atoms), 67)



if __name__ == '__main__':
    test_cases = [
        'AD4flex_readflexTests',
        'AD4flex_formatting_flexResTests',
        #'AD4flex_hingeTests',
            ]
    unittest.main( argv=([__name__ ,] + test_cases) )
    #unittest.main( argv=([__name__ ,'-v'] + test_cases) )
    #unittest.main()






#
#
#
#
# $Id: test_prepareReceptor.py,v 1.3 2011/09/07 23:02:25 annao Exp $
#

import unittest, os, sys
from string import split, find, strip
from MolKit import Read

class BaseTests(unittest.TestCase):

    def test_default(self):
        """
        test default options 
        options
          [-o pdbqs filename]  (output file)
          [-v]    verbose output          
          [-A]  type(s) of repairs to make:\n\t\t bonds_hydrogens, bonds, hydrogens, None
          [-G]  add Gasteiger charges        
          [-C]  do not add charges        
          [-U]  cleanup by merging/removing:\n\t\t nphs_lps, nphs, lps, waters, nonstdres, 
          [-M]  interactive           automatic 
        """
        testfile = "test_new.pdbqs"
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd +"; ../prepare_receptor.py -r hsg1.pdb -A hydrogens -U nphs_waters -o " + testfile
        os.system(cmd)
        fptr = open(testfile)
        lines = fptr.readlines()
        std_ptr = open("std_hsg1.pdbqs")
        std_lines = std_ptr.readlines()
        ctr = 0
        badlines = []
        for l, std_l in zip(lines, std_lines):
            if find(l, 'ATOM')==0 and find(std_l,'ATOM')==0:
                ind = find(l, '-0.000')
                if ind>-1:
                    l = l[:ind] + ' ' + l[ind+1:]
                ind = find(std_l, '-0.000')
                if ind>-1:
                    std_l = std_l[:ind] + ' ' + l[ind+1:]
                self.assertEqual(l, std_l)



    def test_donot_remove_waters(self):
        """
        test donot remove_waters
        options
           -U nphs.... 
        """
        testfile = "test_keep_waters.pdbqs" 
        cmd = "set PYTHONPATH = %s"%sys.path[0] 
        cmd = cmd + "; ../prepare_receptor.py -r hsg1.pdb -A hydrogens -U nphs -o " + testfile
        #cmd = "$PYTHONPATH/AutoDockTools/Utilities/prepare_receptor.py -r hsg1.pdb -A hydrogens -U nphs -o " + testfile
        os.system(cmd)
        fptr = open(testfile)
        lines = fptr.readlines()
        std_ptr = open("std_with_waters.pdbqs")
        std_lines = std_ptr.readlines()
        for l, std_l in zip(lines, std_lines):
            if find(l, 'ATOM')==0 and find(std_l,'ATOM')==0:
                ind = find(l, '-0.000')
                if ind>-1:
                    l = l[:ind] + ' ' + l[ind+1:]
                ind = find(std_l, '-0.000')
                if ind>-1:
                    std_l = std_l[:ind] + ' ' + l[ind+1:]
                self.assertEqual(strip(l), strip(std_l))


    def test_remove_non_std_chains(self):
        """
        12/29: need better testmolecule for this one
        test remove_non_std_chains
        options
           -U 
        """
        testfile = "test_no_nonstd_chains.pdbqs"
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + "; ../prepare_receptor.py -r hsg1.pdb -U nphs_nonstdres -A checkhydrogens -o " + testfile
        #cmd = "$PYTHONPATH/AutoDockTools/Utilities/prepare_receptor.py -r hsg1.pdb -A hydrogens -U nphs_nonstdres -o " + testfile
        os.system(cmd)
        fptr = open(testfile)
        lines = fptr.readlines()
        std_ptr = open("std_hsg1.pdbqs")
        std_lines = std_ptr.readlines()
        for l, std_l in zip(lines, std_lines):
            if find(l, 'ATOM')==0 and find(std_l,'ATOM')==0:
                ind = find(l, '-0.000')
                if ind>-1:
                    l = l[:ind] + ' ' + l[ind+1:]
                ind = find(std_l, '-0.000')
                if ind>-1:
                    std_l = std_l[:ind] + ' ' + l[ind+1:]
                self.assertEqual(strip(l), strip(std_l))



#    def test_do_not_add_polar_hydrogens(self):
#        """
#        THIS IS NOT SUPPORTED!!!
#        test do_not_add_polar_hydrogens
#        options
#           -A  repairs==""
#        """
#        testfile = "test_nopolarhydrogens.pdbqs"
#        cmd = "set PYTHONPATH=%s"%sys.path[0]
#        cmd = cmd + "; ../prepare_receptor.py -r hsg1.pdbqs -A '' -o " + testfile
#        #cmd = "$PYTHONPATH/AutoDockTools/Utilities/prepare_receptor.py -r hsg1.pdb -o " + testfile
#        os.system(cmd)
#        sleep(5)
#        fptr = open(testfile)
#        lines = fptr.readlines()
#        std_ptr = open("std_no_polar_hydrogens.pdbqs")
#        std_lines = std_ptr.readlines()
#        for l, std_l in zip(lines, std_lines):
#            if find(l, 'ATOM')==0 and find(std_l,'ATOM')==0:
#                ind = find(l, '-0.000')
#                if ind>-1:
#                    l = l[:ind] + ' ' + l[ind+1:]
#                self.assertEqual(strip(l), strip(std_l))


    def test_add_gasteiger_charges(self):
        """
        test add_gasteiger_charges
        options
           -G 
        """
        testfile = "test_gasteiger.pdbqs" 
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + "; ../prepare_receptor.py -r hsg1.pdbqs  -G -o " + testfile
        #cmd = cmd + "; ../prepare_receptor.py -r hsg1.pdbqs -U waters -G -o " + testfile
        #cmd = "$PYTHONPATH/AutoDockTools/Utilities/prepare_receptor.py -r hsg1.pdb -A hydrogens -U nphs_waters -G -o " + testfile
        os.system(cmd)
        fptr = open(testfile)
        lines = fptr.readlines()
        std_ptr = open("std_gasteiger.pdbqs")
        std_lines = std_ptr.readlines()
        for l, std_l in zip(lines, std_lines):
            if find(l, 'ATOM')==0 and find(std_l,'ATOM')==0:
                ind = find(l, '-0.000')
                if ind>-1:
                    l = l[:ind] + ' ' + l[ind+1:]
                ind = find(std_l, '-0.000')
                if ind>-1:
                    std_l = std_l[:ind] + ' ' + l[ind+1:]
                #self.assertEqual(strip(l), strip(std_l))
                line1 = strip(l).split()
                line2 = strip(std_l).split()
                for s1, s2 in zip(line1, line2):
                    if not s1.isalnum(): self.assertAlmostEqual(float(s1), float(s2), places=2)
                    else: self.assertEqual(s1, s2)
                        

    def test_add_no_charges(self):
        """
        test add_no_charges
        options
           -C 
        """
        testfile = "test_add_no_charges.pdbqs"
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + "; ../prepare_receptor.py -r std_hsg1.pdbqs  -A None -C -o " + testfile
        #cmd = "$PYTHONPATH/AutoDockTools/Utilities/prepare_receptor.py -r std_hsg1.pdbqs -C -o " + testfile
        os.system(cmd)
        fptr = open(testfile)
        lines = fptr.readlines()
        std_ptr = open("std_hsg1.pdbqs")
        std_lines = std_ptr.readlines()
        for l, std_l in zip(lines, std_lines):
            if find(l, 'ATOM')==0 and find(std_l,'ATOM')==0:
                ind = find(l, '-0.000')
                if ind>-1:
                    l = l[:ind] + ' ' + l[ind+1:]
                ind = find(std_l, '-0.000')
                if ind>-1:
                    std_l = std_l[:ind] + ' ' + l[ind+1:]
                self.assertEqual(strip(l), strip(std_l))


    def ztest_do_not_add_bonds(self):
        """
        test do_not_add_bonds
        options
           -A None
        @@need a better file to test for this one...
        """
        
        testfile = "test_do_not_add_bonds.pdbqs"
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + "; ../prepare_receptor.py -r std_hsg1.pdbqs -A checkhydrogens -o " + testfile
        os.system(cmd)
        fptr = open(testfile)
        lines = fptr.readlines()
        std_ptr = open("std_hsg1.pdbqs")
        std_lines = std_ptr.readlines()
        for l, std_l in zip(lines, std_lines):
            if find(l, 'ATOM')==0 and find(std_l,'ATOM')==0:
                ind = find(l, '-0.000')
                if ind>-1:
                    l = l[:ind] + ' ' + l[ind+1:]
                ind = find(std_l, '-0.000')
                if ind>-1:
                    std_l = std_l[:ind] + ' ' + l[ind+1:]
                self.assertEqual(l, std_l)




if __name__ == '__main__':
    unittest.main()
